countryDict = {'ABW': {'alpha2': 'AW',
                       'alpha3': 'ABW',
                       'area_km': 193,
                       'area_miles': 75,
                       'area_ranking': 220,
                       'capital': 'Oranjestad',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/f6/Flag_of_Aruba.svg/1920px-Flag_of_Aruba.svg.png',
                       'gdp': 3293000000,
                       'gdp_per_capita': 30662,
                       'gdp_per_capita_ranking': 56,
                       'gdp_ranking': 178,
                       'largest_city': 'Oranjestad',
                       'name': 'Aruba',
                       'population': 107394,
                       'population_density_km': 556.45,
                       'population_density_miles': 1431.92,
                       'population_density_ranking': 21,
                       'population_ranking': 194},
               'AFG': {'alpha2': 'AF',
                       'alpha3': 'AFG',
                       'area_km': 652230,
                       'area_miles': 251827,
                       'area_ranking': 41,
                       'capital': 'Kabul',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/5c/Flag_of_the_Taliban.svg/2560px-Flag_of_the_Taliban.svg.png',
                       'gdp': 17876000000,
                       'gdp_per_capita': 646,
                       'gdp_per_capita_ranking': 229,
                       'gdp_ranking': 121,
                       'largest_city': 'Kabul',
                       'name': 'Afghanistan',
                       'official_name': 'Islamic Republic of Afghanistan',
                       'population': 27657145,
                       'population_density_km': 42.4,
                       'population_density_miles': 109.83,
                       'population_density_ranking': 170,
                       'population_ranking': 46},
               'AGO': {'alpha2': 'AO',
                       'alpha3': 'AGO',
                       'area_km': 1246700,
                       'area_miles': 481352,
                       'area_ranking': 23,
                       'capital': 'Luanda',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9d/Flag_of_Angola.svg/1280px-Flag_of_Angola.svg.png',
                       'gdp': 85000000000,
                       'gdp_per_capita': 3285,
                       'gdp_per_capita_ranking': 181,
                       'gdp_ranking': 69,
                       'largest_city': 'Luanda',
                       'name': 'Angola',
                       'official_name': 'Republic of Angola',
                       'population': 25868000,
                       'population_density_km': 20.75,
                       'population_density_miles': 53.74,
                       'population_density_ranking': 195,
                       'population_ranking': 49},
               'AIA': {'alpha2': 'AI',
                       'alpha3': 'AIA',
                       'area_km': 91,
                       'area_miles': 36,
                       'area_ranking': 230,
                       'capital': 'The Valley',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b4/Flag_of_Anguilla.svg/2560px-Flag_of_Anguilla.svg.png',
                       'gdp': 379000000,
                       'gdp_per_capita': 28174,
                       'gdp_per_capita_ranking': 61,
                       'gdp_ranking': 221,
                       'largest_city': 'The Valley',
                       'name': 'Anguilla',
                       'population': 13452,
                       'population_density_km': 147.82,
                       'population_density_miles': 373.67,
                       'population_density_ranking': 79,
                       'population_ranking': 226},
               'ALA': {'alpha2': 'AX',
                       'alpha3': 'ALA',
                       'area_km': 1580,
                       'area_miles': 611,
                       'area_ranking': 184,
                       'capital': 'Mariehamn',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/52/Flag_of_%C3%85land.svg/1920px-Flag_of_%C3%85land.svg.png',
                       'gdp': 1503000000,
                       'gdp_per_capita': 52051,
                       'gdp_per_capita_ranking': 26,
                       'gdp_ranking': 201,
                       'largest_city': 'Mariehamn',
                       'name': 'Åland Islands',
                       'population': 28875,
                       'population_density_km': 18.28,
                       'population_density_miles': 47.26,
                       'population_density_ranking': 200,
                       'population_ranking': 221},
               'ALB': {'alpha2': 'AL',
                       'alpha3': 'ALB',
                       'area_km': 27398,
                       'area_miles': 10579,
                       'area_ranking': 147,
                       'capital': 'Tirana',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/36/Flag_of_Albania.svg/1920px-Flag_of_Albania.svg.png',
                       'gdp': 15278000000,
                       'gdp_per_capita': 5293,
                       'gdp_per_capita_ranking': 151,
                       'gdp_ranking': 130,
                       'largest_city': 'Tirana',
                       'name': 'Albania',
                       'official_name': 'Republic of Albania',
                       'population': 2886026,
                       'population_density_km': 105.34,
                       'population_density_miles': 272.81,
                       'population_density_ranking': 105,
                       'population_ranking': 138},
               'AND': {'alpha2': 'AD',
                       'alpha3': 'AND',
                       'area_km': 468,
                       'area_miles': 181,
                       'area_ranking': 199,
                       'capital': 'Andorra la Vella',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/19/Flag_of_Andorra.svg/1280px-Flag_of_Andorra.svg.png',
                       'gdp': 3154000000,
                       'gdp_per_capita': 40428,
                       'gdp_per_capita_ranking': 43,
                       'gdp_ranking': 181,
                       'largest_city': 'Andorra la Vella',
                       'name': 'Andorra',
                       'official_name': 'Principality of Andorra',
                       'population': 78014,
                       'population_density_km': 166.7,
                       'population_density_miles': 431.02,
                       'population_density_ranking': 77,
                       'population_ranking': 202},
               'ARE': {'alpha2': 'AE',
                       'alpha3': 'ARE',
                       'area_km': 83600,
                       'area_miles': 32278,
                       'area_ranking': 114,
                       'capital': 'Abu Dhabi',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/cb/Flag_of_the_United_Arab_Emirates.svg/1920px-Flag_of_the_United_Arab_Emirates.svg.png',
                       'gdp': 421142000000,
                       'gdp_per_capita': 42729,
                       'gdp_per_capita_ranking': 41,
                       'gdp_ranking': 29,
                       'largest_city': 'Dubai',
                       'name': 'United Arab Emirates',
                       'population': 9856000,
                       'population_density_km': 117.89,
                       'population_density_miles': 305.35,
                       'population_density_ranking': 96,
                       'population_ranking': 89},
               'ARG': {'alpha2': 'AR',
                       'alpha3': 'ARG',
                       'area_km': 2736690,
                       'area_miles': 1056638,
                       'area_ranking': 8,
                       'capital': 'Buenos Aires',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/1a/Flag_of_Argentina.svg/1280px-Flag_of_Argentina.svg.png',
                       'gdp': 449663000000,
                       'gdp_per_capita': 10315,
                       'gdp_per_capita_ranking': 115,
                       'gdp_ranking': 27,
                       'largest_city': 'Buenos Aires',
                       'name': 'Argentina',
                       'official_name': 'Argentine Republic',
                       'population': 43590400,
                       'population_density_km': 15.93,
                       'population_density_miles': 41.25,
                       'population_density_ranking': 209,
                       'population_ranking': 31},
               'ARM': {'alpha2': 'AM',
                       'alpha3': 'ARM',
                       'area_km': 28342,
                       'area_miles': 10943,
                       'area_ranking': 142,
                       'capital': 'Yerevan',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/2f/Flag_of_Armenia.svg/800px-Flag_of_Armenia.svg.png',
                       'gdp': 13672000000,
                       'gdp_per_capita': 4565,
                       'gdp_per_capita_ranking': 159,
                       'gdp_ranking': 136,
                       'largest_city': 'Yerevan',
                       'name': 'Armenia',
                       'official_name': 'Republic of Armenia',
                       'population': 2994400,
                       'population_density_km': 105.65,
                       'population_density_miles': 273.64,
                       'population_density_ranking': 104,
                       'population_ranking': 137},
               'ASM': {'alpha2': 'AS',
                       'alpha3': 'ASM',
                       'area_km': 200,
                       'area_miles': 78,
                       'area_ranking': 219,
                       'capital': 'Pago Pago',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/87/Flag_of_American_Samoa.svg/2560px-Flag_of_American_Samoa.svg.png',
                       'gdp': 636000000,
                       'gdp_per_capita': 11138,
                       'gdp_per_capita_ranking': 113,
                       'gdp_ranking': 214,
                       'largest_city': 'Tāfuna',
                       'name': 'American Samoa',
                       'population': 57100,
                       'population_density_km': 285.5,
                       'population_density_miles': 732.05,
                       'population_density_ranking': 50,
                       'population_ranking': 207},
               'ATF': {'alpha2': 'TF',
                       'alpha3': 'ATF',
                       'area_km': 11249,
                       'area_miles': 4344,
                       'area_ranking': 165,
                       'capital': 'Port-aux-Français',
                       'continent': 'ANTARCTICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/a/a7/Flag_of_the_French_Southern_and_Antarctic_Lands.svg/1920px-Flag_of_the_French_Southern_and_Antarctic_Lands.svg.png',
                       'gdp': 0,
                       'gdp_per_capita': 0,
                       'gdp_per_capita_ranking': 243,
                       'gdp_ranking': 243,
                       'largest_city': 'Port-aux-Français',
                       'name': 'French Southern Territories',
                       'population': 140,
                       'population_density_km': 0.01,
                       'population_density_miles': 0.03,
                       'population_density_ranking': 244,
                       'population_ranking': 245},
               'ATG': {'alpha2': 'AG',
                       'alpha3': 'ATG',
                       'area_km': 442,
                       'area_miles': 171,
                       'area_ranking': 204,
                       'capital': "Saint John's",
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/89/Flag_of_Antigua_and_Barbuda.svg/1280px-Flag_of_Antigua_and_Barbuda.svg.png',
                       'gdp': 1661000000,
                       'gdp_per_capita': 19247,
                       'gdp_per_capita_ranking': 81,
                       'gdp_ranking': 198,
                       'largest_city': "St. John's",
                       'name': 'Antigua and Barbuda',
                       'population': 86295,
                       'population_density_km': 195.24,
                       'population_density_miles': 504.65,
                       'population_density_ranking': 70,
                       'population_ranking': 200},
               'AUS': {'alpha2': 'AU',
                       'alpha3': 'AUS',
                       'area_km': 7633565,
                       'area_miles': 2947323,
                       'area_ranking': 6,
                       'capital': 'Canberra',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/88/Flag_of_Australia_%28converted%29.svg/800px-Flag_of_Australia_%28converted%29.svg.png',
                       'gdp': 1380207000000,
                       'gdp_per_capita': 57228,
                       'gdp_per_capita_ranking': 22,
                       'gdp_ranking': 14,
                       'largest_city': 'Sydney',
                       'name': 'Australia',
                       'population': 24117360,
                       'population_density_km': 3.16,
                       'population_density_miles': 8.18,
                       'population_density_ranking': 235,
                       'population_ranking': 51},
               'AUT': {'alpha2': 'AT',
                       'alpha3': 'AUT',
                       'area_km': 82445,
                       'area_miles': 31833,
                       'area_ranking': 116,
                       'capital': 'Vienna',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/41/Flag_of_Austria.svg/800px-Flag_of_Austria.svg.png',
                       'gdp': 445075000000,
                       'gdp_per_capita': 51006,
                       'gdp_per_capita_ranking': 27,
                       'gdp_ranking': 28,
                       'largest_city': 'Vienna',
                       'name': 'Austria',
                       'official_name': 'Republic of Austria',
                       'population': 8725931,
                       'population_density_km': 105.84,
                       'population_density_miles': 274.12,
                       'population_density_ranking': 103,
                       'population_ranking': 94},
               'AZE': {'alpha2': 'AZ',
                       'alpha3': 'AZE',
                       'area_km': 86100,
                       'area_miles': 33244,
                       'area_ranking': 113,
                       'capital': 'Baku',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/dd/Flag_of_Azerbaijan.svg/800px-Flag_of_Azerbaijan.svg.png',
                       'gdp': 48047000000,
                       'gdp_per_capita': 4937,
                       'gdp_per_capita_ranking': 154,
                       'gdp_ranking': 91,
                       'largest_city': 'Baku',
                       'name': 'Azerbaijan',
                       'official_name': 'Republic of Azerbaijan',
                       'population': 9730500,
                       'population_density_km': 113.01,
                       'population_density_miles': 292.7,
                       'population_density_ranking': 98,
                       'population_ranking': 91},
               'BDI': {'alpha2': 'BI',
                       'alpha3': 'BDI',
                       'area_km': 25680,
                       'area_miles': 9916,
                       'area_ranking': 148,
                       'capital': 'Bujumbura',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/50/Flag_of_Burundi.svg/800px-Flag_of_Burundi.svg.png',
                       'gdp': 3002000000,
                       'gdp_per_capita': 296,
                       'gdp_per_capita_ranking': 241,
                       'gdp_ranking': 186,
                       'largest_city': 'Bujumbura',
                       'name': 'Burundi',
                       'official_name': 'Republic of Burundi',
                       'population': 10114505,
                       'population_density_km': 393.87,
                       'population_density_miles': 1020.02,
                       'population_density_ranking': 33,
                       'population_ranking': 86},
               'BEL': {'alpha2': 'BE',
                       'alpha3': 'BEL',
                       'area_km': 30278,
                       'area_miles': 11691,
                       'area_ranking': 141,
                       'capital': 'Brussels',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/65/Flag_of_Belgium.svg/800px-Flag_of_Belgium.svg.png',
                       'gdp': 533097000000,
                       'gdp_per_capita': 47095,
                       'gdp_per_capita_ranking': 33,
                       'gdp_ranking': 24,
                       'largest_city': 'Brussels',
                       'name': 'Belgium',
                       'official_name': 'Kingdom of Belgium',
                       'population': 11319511,
                       'population_density_km': 373.85,
                       'population_density_miles': 968.22,
                       'population_density_ranking': 36,
                       'population_ranking': 76},
               'BEN': {'alpha2': 'BJ',
                       'alpha3': 'BEN',
                       'area_km': 114305,
                       'area_miles': 44134,
                       'area_ranking': 99,
                       'capital': 'Porto-Novo',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/0a/Flag_of_Benin.svg/800px-Flag_of_Benin.svg.png',
                       'gdp': 14403000000,
                       'gdp_per_capita': 1351,
                       'gdp_per_capita_ranking': 212,
                       'gdp_ranking': 132,
                       'largest_city': 'Cotonou',
                       'name': 'Benin',
                       'official_name': 'Republic of Benin',
                       'population': 10653654,
                       'population_density_km': 93.2,
                       'population_density_miles': 241.39,
                       'population_density_ranking': 114,
                       'population_ranking': 83},
               'BES': {'alpha2': 'BQ',
                       'alpha3': 'BES',
                       'area_km': 322,
                       'area_miles': 125,
                       'area_ranking': 211,
                       'capital': 'Kralendijk',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/1e/Flag_of_Bonaire.svg/1200px-Flag_of_Bonaire.svg.png',
                       'gdp': 583000000,
                       'gdp_per_capita': 33490,
                       'gdp_per_capita_ranking': 51,
                       'gdp_ranking': 216,
                       'largest_city': 'Kralendijk',
                       'name': 'Caribbean Netherlands',
                       'official_name': 'Bonaire, Sint Eustatius and Saba',
                       'population': 17408,
                       'population_density_km': 54.06,
                       'population_density_miles': 139.26,
                       'population_density_ranking': 152,
                       'population_ranking': 225},
               'BFA': {'alpha2': 'BF',
                       'alpha3': 'BFA',
                       'area_km': 273602,
                       'area_miles': 105638,
                       'area_ranking': 74,
                       'capital': 'Ouagadougou',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/31/Flag_of_Burkina_Faso.svg/800px-Flag_of_Burkina_Faso.svg.png',
                       'gdp': 15990000000,
                       'gdp_per_capita': 840,
                       'gdp_per_capita_ranking': 226,
                       'gdp_ranking': 127,
                       'largest_city': 'Ouagadougou',
                       'name': 'Burkina Faso',
                       'population': 19034397,
                       'population_density_km': 69.57,
                       'population_density_miles': 180.19,
                       'population_density_ranking': 140,
                       'population_ranking': 59},
               'BGD': {'alpha2': 'BD',
                       'alpha3': 'BGD',
                       'area_km': 130168,
                       'area_miles': 50258,
                       'area_ranking': 96,
                       'capital': 'Dhaka',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/f9/Flag_of_Bangladesh.svg/800px-Flag_of_Bangladesh.svg.png',
                       'gdp': 317465000000,
                       'gdp_per_capita': 1971,
                       'gdp_per_capita_ranking': 199,
                       'gdp_ranking': 40,
                       'largest_city': 'Dhaka',
                       'name': 'Bangladesh',
                       'official_name': "People's Republic of Bangladesh",
                       'population': 161006790,
                       'population_density_km': 1236.92,
                       'population_density_miles': 3203.61,
                       'population_density_ranking': 9,
                       'population_ranking': 8},
               'BGR': {'alpha2': 'BG',
                       'alpha3': 'BGR',
                       'area_km': 108612,
                       'area_miles': 41936,
                       'area_ranking': 102,
                       'capital': 'Sofia',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9a/Flag_of_Bulgaria.svg/800px-Flag_of_Bulgaria.svg.png',
                       'gdp': 67925000000,
                       'gdp_per_capita': 9494,
                       'gdp_per_capita_ranking': 121,
                       'gdp_ranking': 75,
                       'largest_city': 'Sofia',
                       'name': 'Bulgaria',
                       'official_name': 'Republic of Bulgaria',
                       'population': 7153784,
                       'population_density_km': 65.87,
                       'population_density_miles': 170.59,
                       'population_density_ranking': 142,
                       'population_ranking': 101},
               'BHR': {'alpha2': 'BH',
                       'alpha3': 'BHR',
                       'area_km': 778,
                       'area_miles': 301,
                       'area_ranking': 190,
                       'capital': 'Manama',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/2c/Flag_of_Bahrain.svg/800px-Flag_of_Bahrain.svg.png',
                       'gdp': 38574000000,
                       'gdp_per_capita': 27456,
                       'gdp_per_capita_ranking': 62,
                       'gdp_ranking': 97,
                       'largest_city': 'Manama',
                       'name': 'Bahrain',
                       'official_name': 'Kingdom of Bahrain',
                       'population': 1404900,
                       'population_density_km': 1805.78,
                       'population_density_miles': 4667.44,
                       'population_density_ranking': 6,
                       'population_ranking': 151},
               'BHS': {'alpha2': 'BS',
                       'alpha3': 'BHS',
                       'area_km': 10010,
                       'area_miles': 3865,
                       'area_ranking': 168,
                       'capital': 'Nassau',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/93/Flag_of_the_Bahamas.svg/800px-Flag_of_the_Bahamas.svg.png',
                       'gdp': 13578000000,
                       'gdp_per_capita': 35916,
                       'gdp_per_capita_ranking': 47,
                       'gdp_ranking': 137,
                       'largest_city': 'Nassaug',
                       'name': 'Bahamas',
                       'official_name': 'Commonwealth of the Bahamas',
                       'population': 378040,
                       'population_density_km': 37.77,
                       'population_density_miles': 97.81,
                       'population_density_ranking': 175,
                       'population_ranking': 177},
               'BIH': {'alpha2': 'BA',
                       'alpha3': 'BIH',
                       'area_km': 51187,
                       'area_miles': 19764,
                       'area_ranking': 129,
                       'capital': 'Sarajevo',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/bf/Flag_of_Bosnia_and_Herzegovina.svg/800px-Flag_of_Bosnia_and_Herzegovina.svg.png',
                       'gdp': 20164000000,
                       'gdp_per_capita': 5710,
                       'gdp_per_capita_ranking': 148,
                       'gdp_ranking': 118,
                       'largest_city': 'Sarajevo',
                       'name': 'Bosnia and Herzegovina',
                       'official_name': 'Republic of Bosnia and Herzegovina',
                       'population': 3531159,
                       'population_density_km': 68.99,
                       'population_density_miles': 178.67,
                       'population_density_ranking': 141,
                       'population_ranking': 133},
               'BLM': {'alpha2': 'BL',
                       'alpha3': 'BLM',
                       'area_km': 25,
                       'area_miles': 10,
                       'area_ranking': 239,
                       'capital': 'Gustavia',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/c/c3/Flag_of_France.svg/1920px-Flag_of_France.svg.png',
                       'gdp': 191000000,
                       'gdp_per_capita': 20282,
                       'gdp_per_capita_ranking': 77,
                       'gdp_ranking': 229,
                       'largest_city': 'Gustavia',
                       'name': 'Saint Barthélemy',
                       'population': 9417,
                       'population_density_km': 376.68,
                       'population_density_miles': 941.7,
                       'population_density_ranking': 35,
                       'population_ranking': 230},
               'BLR': {'alpha2': 'BY',
                       'alpha3': 'BLR',
                       'area_km': 202900,
                       'area_miles': 78340,
                       'area_ranking': 83,
                       'capital': 'Minsk',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/85/Flag_of_Belarus.svg/800px-Flag_of_Belarus.svg.png',
                       'gdp': 63080000000,
                       'gdp_per_capita': 6640,
                       'gdp_per_capita_ranking': 140,
                       'gdp_ranking': 78,
                       'largest_city': 'Minsk',
                       'name': 'Belarus',
                       'official_name': 'Republic of Belarus',
                       'population': 9498700,
                       'population_density_km': 46.81,
                       'population_density_miles': 121.25,
                       'population_density_ranking': 165,
                       'population_ranking': 93},
               'BLZ': {'alpha2': 'BZ',
                       'alpha3': 'BLZ',
                       'area_km': 22806,
                       'area_miles': 8806,
                       'area_ranking': 152,
                       'capital': 'Belmopan',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/e7/Flag_of_Belize.svg/800px-Flag_of_Belize.svg.png',
                       'gdp': 1906000000,
                       'gdp_per_capita': 5147,
                       'gdp_per_capita_ranking': 152,
                       'gdp_ranking': 195,
                       'largest_city': 'Belize City',
                       'name': 'Belize',
                       'population': 370300,
                       'population_density_km': 16.24,
                       'population_density_miles': 42.05,
                       'population_density_ranking': 208,
                       'population_ranking': 178},
               'BMU': {'alpha2': 'BM',
                       'alpha3': 'BMU',
                       'area_km': 53,
                       'area_miles': 21,
                       'area_ranking': 233,
                       'capital': 'Hamilton',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/bf/Flag_of_Bermuda.svg/2560px-Flag_of_Bermuda.svg.png',
                       'gdp': 7361000000,
                       'gdp_per_capita': 118813,
                       'gdp_per_capita_ranking': 4,
                       'gdp_ranking': 159,
                       'largest_city': 'Hamilton',
                       'name': 'Bermuda',
                       'population': 61954,
                       'population_density_km': 1168.94,
                       'population_density_miles': 2950.19,
                       'population_density_ranking': 10,
                       'population_ranking': 205},
               'BOL': {'alpha2': 'BO',
                       'alpha3': 'BOL',
                       'area_km': 1083301,
                       'area_miles': 418263,
                       'area_ranking': 26,
                       'capital': 'Sucre',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b3/Bandera_de_Bolivia_%28Estado%29.svg/800px-Bandera_de_Bolivia_%28Estado%29.svg.png',
                       'gdp': 40895000000,
                       'gdp_per_capita': 3722,
                       'gdp_per_capita_ranking': 171,
                       'gdp_ranking': 94,
                       'largest_city': 'Santa Cruz de la Sierra',
                       'name': 'Bolivia',
                       'official_name': 'Plurinational State of Bolivia',
                       'population': 10985059,
                       'population_density_km': 10.14,
                       'population_density_miles': 26.26,
                       'population_density_ranking': 218,
                       'population_ranking': 81},
               'BRA': {'alpha2': 'BR',
                       'alpha3': 'BRA',
                       'area_km': 8460415,
                       'area_miles': 3266570,
                       'area_ranking': 5,
                       'capital': 'Brasília',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/0/05/Flag_of_Brazil.svg/800px-Flag_of_Brazil.svg.png',
                       'gdp': 1847795000000,
                       'gdp_per_capita': 8963,
                       'gdp_per_capita_ranking': 126,
                       'gdp_ranking': 9,
                       'largest_city': 'São Paulo',
                       'name': 'Brazil',
                       'official_name': 'Federative Republic of Brazil',
                       'population': 206135893,
                       'population_density_km': 24.36,
                       'population_density_miles': 63.1,
                       'population_density_ranking': 190,
                       'population_ranking': 5},
               'BRB': {'alpha2': 'BB',
                       'alpha3': 'BRB',
                       'area_km': 431,
                       'area_miles': 167,
                       'area_ranking': 205,
                       'capital': 'Bridgetown',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/ef/Flag_of_Barbados.svg/800px-Flag_of_Barbados.svg.png',
                       'gdp': 5209000000,
                       'gdp_per_capita': 18277,
                       'gdp_per_capita_ranking': 86,
                       'gdp_ranking': 169,
                       'largest_city': 'Bridgetown',
                       'name': 'Barbados',
                       'population': 285000,
                       'population_density_km': 661.25,
                       'population_density_miles': 1706.59,
                       'population_density_ranking': 17,
                       'population_ranking': 181},
               'BRN': {'alpha2': 'BN',
                       'alpha3': 'BRN',
                       'area_km': 5265,
                       'area_miles': 2033,
                       'area_ranking': 173,
                       'capital': 'Bandar Seri Begawan',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9c/Flag_of_Brunei.svg/800px-Flag_of_Brunei.svg.png',
                       'gdp': 13469000000,
                       'gdp_per_capita': 32699,
                       'gdp_per_capita_ranking': 53,
                       'gdp_ranking': 138,
                       'largest_city': 'Bandar Seri Begawan',
                       'name': 'Brunei',
                       'population': 411900,
                       'population_density_km': 78.23,
                       'population_density_miles': 202.61,
                       'population_density_ranking': 129,
                       'population_ranking': 174},
               'BTN': {'alpha2': 'BT',
                       'alpha3': 'BTN',
                       'area_km': 38394,
                       'area_miles': 14824,
                       'area_ranking': 136,
                       'capital': 'Thimphu',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/91/Flag_of_Bhutan.svg/800px-Flag_of_Bhutan.svg.png',
                       'gdp': 2564000000,
                       'gdp_per_capita': 3305,
                       'gdp_per_capita_ranking': 180,
                       'gdp_ranking': 188,
                       'largest_city': 'Thimphu',
                       'name': 'Bhutan',
                       'official_name': 'Kingdom of Bhutan',
                       'population': 775620,
                       'population_density_km': 20.2,
                       'population_density_miles': 52.32,
                       'population_density_ranking': 197,
                       'population_ranking': 164},
               'BWA': {'alpha2': 'BW',
                       'alpha3': 'BWA',
                       'area_km': 566730,
                       'area_miles': 218815,
                       'area_ranking': 48,
                       'capital': 'Gaborone',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fa/Flag_of_Botswana.svg/800px-Flag_of_Botswana.svg.png',
                       'gdp': 18340000000,
                       'gdp_per_capita': 8565,
                       'gdp_per_capita_ranking': 129,
                       'gdp_ranking': 120,
                       'largest_city': 'Gaborone',
                       'name': 'Botswana',
                       'official_name': 'Republic of Botswana',
                       'population': 2141206,
                       'population_density_km': 3.78,
                       'population_density_miles': 9.79,
                       'population_density_ranking': 230,
                       'population_ranking': 143},
               'CAF': {'alpha2': 'CF',
                       'alpha3': 'CAF',
                       'area_km': 622984,
                       'area_miles': 240535,
                       'area_ranking': 44,
                       'capital': 'Bangui',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/6f/Flag_of_the_Central_African_Republic.svg/1024px-Flag_of_the_Central_African_Republic.svg.png',
                       'gdp': 2220000000,
                       'gdp_per_capita': 444,
                       'gdp_per_capita_ranking': 238,
                       'gdp_ranking': 190,
                       'largest_city': 'Bangui',
                       'name': 'Central African Republic',
                       'population': 4998000,
                       'population_density_km': 8.02,
                       'population_density_miles': 20.78,
                       'population_density_ranking': 222,
                       'population_ranking': 119},
               'CAN': {'alpha2': 'CA',
                       'alpha3': 'CAN',
                       'area_km': 9093507,
                       'area_miles': 3511007,
                       'area_ranking': 4,
                       'capital': 'Ottawa',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d9/Flag_of_Canada_%28Pantone%29.svg/2560px-Flag_of_Canada_%28Pantone%29.svg.png',
                       'gdp': 1741496000000,
                       'gdp_per_capita': 48166,
                       'gdp_per_capita_ranking': 31,
                       'gdp_ranking': 10,
                       'largest_city': 'Toronto',
                       'name': 'Canada',
                       'population': 36155487,
                       'population_density_km': 3.98,
                       'population_density_miles': 10.3,
                       'population_density_ranking': 228,
                       'population_ranking': 36},
               'CCK': {'alpha2': 'CC',
                       'alpha3': 'CCK',
                       'area_km': 14,
                       'area_miles': 6,
                       'area_ranking': 242,
                       'capital': 'West Island',
                       'continent': 'VOID',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/74/Flag_of_the_Cocos_%28Keeling%29_Islands.svg/2560px-Flag_of_the_Cocos_%28Keeling%29_Islands.svg.png',
                       'gdp': 11012550,
                       'gdp_per_capita': 20022,
                       'gdp_per_capita_ranking': 79,
                       'gdp_ranking': 239,
                       'largest_city': 'Bantam',
                       'name': 'Cocos (Keeling) Islands',
                       'population': 550,
                       'population_density_km': 39.29,
                       'population_density_miles': 91.67,
                       'population_density_ranking': 171,
                       'population_ranking': 242},
               'CHE': {'alpha2': 'CH',
                       'alpha3': 'CHE',
                       'area_km': 39997,
                       'area_miles': 15443,
                       'area_ranking': 135,
                       'capital': 'Bern',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/f3/Flag_of_Switzerland.svg/1024px-Flag_of_Switzerland.svg.png',
                       'gdp': 731425000000,
                       'gdp_per_capita': 87684,
                       'gdp_per_capita_ranking': 9,
                       'gdp_ranking': 20,
                       'largest_city': 'Zürich',
                       'name': 'Switzerland',
                       'official_name': 'Swiss Confederation',
                       'population': 8341600,
                       'population_density_km': 208.56,
                       'population_density_miles': 540.15,
                       'population_density_ranking': 64,
                       'population_ranking': 98},
               'CHL': {'alpha2': 'CL',
                       'alpha3': 'CHL',
                       'area_km': 743812,
                       'area_miles': 287187,
                       'area_ranking': 38,
                       'capital': 'Santiago',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/78/Flag_of_Chile.svg/1024px-Flag_of_Chile.svg.png',
                       'gdp': 282318000000,
                       'gdp_per_capita': 15518,
                       'gdp_per_capita_ranking': 97,
                       'gdp_ranking': 43,
                       'largest_city': 'Santiago',
                       'name': 'Chile',
                       'official_name': 'Republic of Chile',
                       'population': 18191900,
                       'population_density_km': 24.46,
                       'population_density_miles': 63.35,
                       'population_density_ranking': 189,
                       'population_ranking': 61},
               'CHN': {'alpha2': 'CN',
                       'alpha3': 'CHN',
                       'area_km': 9326410,
                       'area_miles': 3600931,
                       'area_ranking': 2,
                       'capital': 'Beijing',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fa/Flag_of_the_People%27s_Republic_of_China.svg/1024px-Flag_of_the_People%27s_Republic_of_China.svg.png',
                       'gdp': 14342933000000,
                       'gdp_per_capita': 10412,
                       'gdp_per_capita_ranking': 114,
                       'gdp_ranking': 2,
                       'largest_city': 'Shanghai',
                       'name': 'China',
                       'official_name': "People's Republic of China",
                       'population': 1377422166,
                       'population_density_km': 147.69,
                       'population_density_miles': 382.52,
                       'population_density_ranking': 81,
                       'population_ranking': 1},
               'CIV': {'alpha2': 'CI',
                       'alpha3': 'CIV',
                       'area_km': 318003,
                       'area_miles': 122782,
                       'area_ranking': 67,
                       'capital': 'Yamoussoukro',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fe/Flag_of_C%C3%B4te_d%27Ivoire.svg/800px-Flag_of_C%C3%B4te_d%27Ivoire.svg.png',
                       'gdp': 58539000000,
                       'gdp_per_capita': 2582,
                       'gdp_per_capita_ranking': 190,
                       'gdp_ranking': 82,
                       'largest_city': 'Abidjan',
                       'name': "Côte d'Ivoire",
                       'official_name': "Republic of Côte d'Ivoire",
                       'population': 22671331,
                       'population_density_km': 71.29,
                       'population_density_miles': 184.65,
                       'population_density_ranking': 139,
                       'population_ranking': 54},
               'CMR': {'alpha2': 'CM',
                       'alpha3': 'CMR',
                       'area_km': 472710,
                       'area_miles': 182514,
                       'area_ranking': 53,
                       'capital': 'Yaoundé',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/4f/Flag_of_Cameroon.svg/1024px-Flag_of_Cameroon.svg.png',
                       'gdp': 38861000000,
                       'gdp_per_capita': 1711,
                       'gdp_per_capita_ranking': 203,
                       'gdp_ranking': 95,
                       'largest_city': 'Yaoundé',
                       'name': 'Cameroon',
                       'official_name': 'Republic of Cameroon',
                       'population': 22709892,
                       'population_density_km': 48.04,
                       'population_density_miles': 124.43,
                       'population_density_ranking': 161,
                       'population_ranking': 53},
               'COD': {'alpha2': 'CD',
                       'alpha3': 'COD',
                       'area_km': 2267048,
                       'area_miles': 875309,
                       'area_ranking': 11,
                       'capital': 'Kinshasa',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/6f/Flag_of_the_Democratic_Republic_of_the_Congo.svg/1024px-Flag_of_the_Democratic_Republic_of_the_Congo.svg.png',
                       'gdp': 47319000000,
                       'gdp_per_capita': 556,
                       'gdp_per_capita_ranking': 236,
                       'gdp_ranking': 92,
                       'largest_city': 'Kinshasa',
                       'name': 'Democratic Republic of the Congo',
                       'population': 85026000,
                       'population_density_km': 37.51,
                       'population_density_miles': 97.14,
                       'population_density_ranking': 176,
                       'population_ranking': 16},
               'COG': {'alpha2': 'CG',
                       'alpha3': 'COG',
                       'area_km': 342000,
                       'area_miles': 132047,
                       'area_ranking': 65,
                       'capital': 'Brazzaville',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/92/Flag_of_the_Republic_of_the_Congo.svg/1024px-Flag_of_the_Republic_of_the_Congo.svg.png',
                       'gdp': 12397000000,
                       'gdp_per_capita': 2614,
                       'gdp_per_capita_ranking': 189,
                       'gdp_ranking': 142,
                       'largest_city': 'Brazzaville',
                       'name': 'Republic of the Congo',
                       'official_name': 'Republic of the Congo',
                       'population': 4741000,
                       'population_density_km': 13.86,
                       'population_density_miles': 35.9,
                       'population_density_ranking': 216,
                       'population_ranking': 122},
               'COK': {'alpha2': 'CK',
                       'alpha3': 'COK',
                       'area_km': 237,
                       'area_miles': 92,
                       'area_ranking': 218,
                       'capital': 'Avarua',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/35/Flag_of_the_Cook_Islands.svg/2560px-Flag_of_the_Cook_Islands.svg.png',
                       'gdp': 379000000,
                       'gdp_per_capita': 20939,
                       'gdp_per_capita_ranking': 75,
                       'gdp_ranking': 222,
                       'largest_city': 'Avarua',
                       'name': 'Cook Islands',
                       'population': 18100,
                       'population_density_km': 76.37,
                       'population_density_miles': 196.74,
                       'population_density_ranking': 133,
                       'population_ranking': 223},
               'COL': {'alpha2': 'CO',
                       'alpha3': 'COL',
                       'area_km': 1038700,
                       'area_miles': 401043,
                       'area_ranking': 27,
                       'capital': 'Bogotá',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/21/Flag_of_Colombia.svg/1024px-Flag_of_Colombia.svg.png',
                       'gdp': 323802000000,
                       'gdp_per_capita': 6640,
                       'gdp_per_capita_ranking': 141,
                       'gdp_ranking': 39,
                       'largest_city': 'Bogotá',
                       'name': 'Colombia',
                       'official_name': 'Republic of Colombia',
                       'population': 48759958,
                       'population_density_km': 46.94,
                       'population_density_miles': 121.58,
                       'population_density_ranking': 164,
                       'population_ranking': 28},
               'COM': {'alpha2': 'KM',
                       'alpha3': 'COM',
                       'area_km': 1862,
                       'area_miles': 719,
                       'area_ranking': 182,
                       'capital': 'Moroni',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/94/Flag_of_the_Comoros.svg/1024px-Flag_of_the_Comoros.svg.png',
                       'gdp': 1165000000,
                       'gdp_per_capita': 1445,
                       'gdp_per_capita_ranking': 209,
                       'gdp_ranking': 208,
                       'largest_city': 'Moroni',
                       'name': 'Comoros',
                       'official_name': 'Union of the Comoros',
                       'population': 806153,
                       'population_density_km': 432.95,
                       'population_density_miles': 1121.21,
                       'population_density_ranking': 29,
                       'population_ranking': 163},
               'CPV': {'alpha2': 'CV',
                       'alpha3': 'CPV',
                       'area_km': 4033,
                       'area_miles': 1558,
                       'area_ranking': 176,
                       'capital': 'Praia',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/a/ae/Flag_of_Cape_Verde_%282-3_ratio%29.svg/800px-Flag_of_Cape_Verde_%282-3_ratio%29.svg.png',
                       'gdp': 1981000000,
                       'gdp_per_capita': 3729,
                       'gdp_per_capita_ranking': 170,
                       'gdp_ranking': 193,
                       'largest_city': 'Praia',
                       'name': 'Cabo Verde',
                       'official_name': 'Republic of Cabo Verde',
                       'population': 531239,
                       'population_density_km': 131.72,
                       'population_density_miles': 340.97,
                       'population_density_ranking': 89,
                       'population_ranking': 171},
               'CRI': {'alpha2': 'CR',
                       'alpha3': 'CRI',
                       'area_km': 51060,
                       'area_miles': 19715,
                       'area_ranking': 130,
                       'capital': 'San José',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/bc/Flag_of_Costa_Rica_%28state%29.svg/1024px-Flag_of_Costa_Rica_%28state%29.svg.png',
                       'gdp': 61773000000,
                       'gdp_per_capita': 12631,
                       'gdp_per_capita_ranking': 105,
                       'gdp_ranking': 79,
                       'largest_city': 'San José',
                       'name': 'Costa Rica',
                       'official_name': 'Republic of Costa Rica',
                       'population': 4890379,
                       'population_density_km': 95.78,
                       'population_density_miles': 248.05,
                       'population_density_ranking': 111,
                       'population_ranking': 120},
               'CUB': {'alpha2': 'CU',
                       'alpha3': 'CUB',
                       'area_km': 109884,
                       'area_miles': 42427,
                       'area_ranking': 101,
                       'capital': 'Havana',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/bd/Flag_of_Cuba.svg/1024px-Flag_of_Cuba.svg.png',
                       'gdp': 105354000000,
                       'gdp_per_capita': 9373,
                       'gdp_per_capita_ranking': 123,
                       'gdp_ranking': 63,
                       'largest_city': 'Havana',
                       'name': 'Cuba',
                       'official_name': 'Republic of Cuba',
                       'population': 11239004,
                       'population_density_km': 102.28,
                       'population_density_miles': 264.9,
                       'population_density_ranking': 108,
                       'population_ranking': 77},
               'CUW': {'alpha2': 'CW',
                       'alpha3': 'CUW',
                       'area_km': 444,
                       'area_miles': 172,
                       'area_ranking': 203,
                       'capital': 'Willemstad',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b1/Flag_of_Cura%C3%A7ao.svg/1920px-Flag_of_Cura%C3%A7ao.svg.png',
                       'gdp': 3101000000,
                       'gdp_per_capita': 20026,
                       'gdp_per_capita_ranking': 78,
                       'gdp_ranking': 183,
                       'largest_city': 'Willemstad',
                       'name': 'Curaçao',
                       'official_name': 'Curaçao',
                       'population': 154843,
                       'population_density_km': 348.75,
                       'population_density_miles': 900.25,
                       'population_density_ranking': 37,
                       'population_ranking': 190},
               'CXR': {'alpha2': 'CX',
                       'alpha3': 'CXR',
                       'area_km': 135,
                       'area_miles': 53,
                       'area_ranking': 225,
                       'capital': 'Flying Fish Cove',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/67/Flag_of_Christmas_Island.svg/2560px-Flag_of_Christmas_Island.svg.png',
                       'gdp': 52177900,
                       'gdp_per_capita': 25182,
                       'gdp_per_capita_ranking': 67,
                       'gdp_ranking': 234,
                       'largest_city': 'Flying Fish Cove',
                       'name': 'Christmas Island',
                       'population': 2072,
                       'population_density_km': 15.35,
                       'population_density_miles': 39.09,
                       'population_density_ranking': 210,
                       'population_ranking': 238},
               'CYM': {'alpha2': 'KY',
                       'alpha3': 'CYM',
                       'area_km': 264,
                       'area_miles': 102,
                       'area_ranking': 214,
                       'capital': 'George Town',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/0f/Flag_of_the_Cayman_Islands.svg/2560px-Flag_of_the_Cayman_Islands.svg.png',
                       'gdp': 6020000000,
                       'gdp_per_capita': 103368,
                       'gdp_per_capita_ranking': 6,
                       'gdp_ranking': 165,
                       'largest_city': 'George Town',
                       'name': 'Cayman Islands',
                       'population': 58238,
                       'population_density_km': 220.6,
                       'population_density_miles': 570.96,
                       'population_density_ranking': 60,
                       'population_ranking': 206},
               'CYP': {'alpha2': 'CY',
                       'alpha3': 'CYP',
                       'area_km': 9241,
                       'area_miles': 3568,
                       'area_ranking': 170,
                       'capital': 'Nicosia',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d4/Flag_of_Cyprus.svg/1024px-Flag_of_Cyprus.svg.png',
                       'gdp': 24565000000,
                       'gdp_per_capita': 29002,
                       'gdp_per_capita_ranking': 60,
                       'gdp_ranking': 110,
                       'largest_city': 'Nicosia',
                       'name': 'Cyprus',
                       'official_name': 'Republic of Cyprus',
                       'population': 847000,
                       'population_density_km': 91.66,
                       'population_density_miles': 237.39,
                       'population_density_ranking': 119,
                       'population_ranking': 161},
               'CZE': {'alpha2': 'CZ',
                       'alpha3': 'CZE',
                       'area_km': 77247,
                       'area_miles': 29826,
                       'area_ranking': 117,
                       'capital': 'Prague',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/cb/Flag_of_the_Czech_Republic.svg/1024px-Flag_of_the_Czech_Republic.svg.png',
                       'gdp': 250680000000,
                       'gdp_per_capita': 23741,
                       'gdp_per_capita_ranking': 71,
                       'gdp_ranking': 47,
                       'largest_city': 'Prague',
                       'name': 'Czech Republic',
                       'official_name': 'Czech Republic',
                       'population': 10558524,
                       'population_density_km': 136.69,
                       'population_density_miles': 354.0,
                       'population_density_ranking': 87,
                       'population_ranking': 84},
               'DEU': {'alpha2': 'DE',
                       'alpha3': 'DEU',
                       'area_km': 348672,
                       'area_miles': 134623,
                       'area_ranking': 64,
                       'capital': 'Berlin',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/b/ba/Flag_of_Germany.svg/1920px-Flag_of_Germany.svg.png',
                       'gdp': 3861123000000,
                       'gdp_per_capita': 47218,
                       'gdp_per_capita_ranking': 32,
                       'gdp_ranking': 4,
                       'largest_city': 'Berlin',
                       'name': 'Germany',
                       'official_name': 'Federal Republic of Germany',
                       'population': 81770900,
                       'population_density_km': 234.52,
                       'population_density_miles': 607.41,
                       'population_density_ranking': 58,
                       'population_ranking': 17},
               'DJI': {'alpha2': 'DJ',
                       'alpha3': 'DJI',
                       'area_km': 23180,
                       'area_miles': 8950,
                       'area_ranking': 151,
                       'capital': 'Djibouti',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/34/Flag_of_Djibouti.svg/1920px-Flag_of_Djibouti.svg.png',
                       'gdp': 3166000000,
                       'gdp_per_capita': 3517,
                       'gdp_per_capita_ranking': 175,
                       'gdp_ranking': 180,
                       'largest_city': 'Djibouti',
                       'name': 'Djibouti',
                       'official_name': 'Republic of Djibouti',
                       'population': 900000,
                       'population_density_km': 38.83,
                       'population_density_miles': 100.56,
                       'population_density_ranking': 173,
                       'population_ranking': 159},
               'DMA': {'alpha2': 'DM',
                       'alpha3': 'DMA',
                       'area_km': 751,
                       'area_miles': 290,
                       'area_ranking': 191,
                       'capital': 'Roseau',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/c4/Flag_of_Dominica.svg/1920px-Flag_of_Dominica.svg.png',
                       'gdp': 582000000,
                       'gdp_per_capita': 8163,
                       'gdp_per_capita_ranking': 131,
                       'gdp_ranking': 217,
                       'largest_city': 'Roseau',
                       'name': 'Dominica',
                       'official_name': 'Commonwealth of Dominica',
                       'population': 71293,
                       'population_density_km': 94.93,
                       'population_density_miles': 245.84,
                       'population_density_ranking': 113,
                       'population_ranking': 203},
               'DNK': {'alpha2': 'DK',
                       'alpha3': 'DNK',
                       'area_km': 42434,
                       'area_miles': 16384,
                       'area_ranking': 133,
                       'capital': 'Copenhagen',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9c/Flag_of_Denmark.svg/1024px-Flag_of_Denmark.svg.png',
                       'gdp': 350104000000,
                       'gdp_per_capita': 61238,
                       'gdp_per_capita_ranking': 21,
                       'gdp_ranking': 38,
                       'largest_city': 'Copenhagen',
                       'name': 'Denmark',
                       'official_name': 'Kingdom of Denmark',
                       'population': 5717014,
                       'population_density_km': 134.73,
                       'population_density_miles': 348.94,
                       'population_density_ranking': 88,
                       'population_ranking': 113},
               'DOM': {'alpha2': 'DO',
                       'alpha3': 'DOM',
                       'area_km': 48320,
                       'area_miles': 18657,
                       'area_ranking': 131,
                       'capital': 'Santo Domingo',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9f/Flag_of_the_Dominican_Republic.svg/1920px-Flag_of_the_Dominican_Republic.svg.png',
                       'gdp': 88941000000,
                       'gdp_per_capita': 8827,
                       'gdp_per_capita_ranking': 128,
                       'gdp_ranking': 68,
                       'largest_city': 'Santo Domingo',
                       'name': 'Dominican Republic',
                       'population': 10075045,
                       'population_density_km': 208.51,
                       'population_density_miles': 540.01,
                       'population_density_ranking': 65,
                       'population_ranking': 87},
               'DZA': {'alpha2': 'DZ',
                       'alpha3': 'DZA',
                       'area_km': 2381741,
                       'area_miles': 919592,
                       'area_ranking': 10,
                       'capital': 'Algiers',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/77/Flag_of_Algeria.svg/1280px-Flag_of_Algeria.svg.png',
                       'gdp': 171157000000,
                       'gdp_per_capita': 4236,
                       'gdp_per_capita_ranking': 165,
                       'gdp_ranking': 56,
                       'largest_city': 'Algiers',
                       'name': 'Algeria',
                       'official_name': "People's Democratic Republic of Algeria",
                       'population': 40400000,
                       'population_density_km': 16.96,
                       'population_density_miles': 43.93,
                       'population_density_ranking': 206,
                       'population_ranking': 33},
               'ECU': {'alpha2': 'EC',
                       'alpha3': 'ECU',
                       'area_km': 256369,
                       'area_miles': 98985,
                       'area_ranking': 77,
                       'capital': 'Quito',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/e8/Flag_of_Ecuador.svg/1920px-Flag_of_Ecuador.svg.png',
                       'gdp': 107435000000,
                       'gdp_per_capita': 6493,
                       'gdp_per_capita_ranking': 142,
                       'gdp_ranking': 62,
                       'largest_city': 'Quito',
                       'name': 'Ecuador',
                       'official_name': 'Republic of Ecuador',
                       'population': 16545799,
                       'population_density_km': 64.54,
                       'population_density_miles': 167.15,
                       'population_density_ranking': 146,
                       'population_ranking': 66},
               'EGY': {'alpha2': 'EG',
                       'alpha3': 'EGY',
                       'area_km': 995450,
                       'area_miles': 384344,
                       'area_ranking': 30,
                       'capital': 'Cairo',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fe/Flag_of_Egypt.svg/1920px-Flag_of_Egypt.svg.png',
                       'gdp': 317359000000,
                       'gdp_per_capita': 3476,
                       'gdp_per_capita_ranking': 178,
                       'gdp_ranking': 41,
                       'largest_city': 'Cairo',
                       'name': 'Egypt',
                       'official_name': 'Arab Republic of Egypt',
                       'population': 91290000,
                       'population_density_km': 91.71,
                       'population_density_miles': 237.52,
                       'population_density_ranking': 118,
                       'population_ranking': 15},
               'ERI': {'alpha2': 'ER',
                       'alpha3': 'ERI',
                       'area_km': 101000,
                       'area_miles': 38997,
                       'area_ranking': 104,
                       'capital': 'Asmara',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/29/Flag_of_Eritrea.svg/1920px-Flag_of_Eritrea.svg.png',
                       'gdp': 1981000000,
                       'gdp_per_capita': 370,
                       'gdp_per_capita_ranking': 240,
                       'gdp_ranking': 194,
                       'largest_city': 'Asmara',
                       'name': 'Eritrea',
                       'official_name': 'the State of Eritrea',
                       'population': 5352000,
                       'population_density_km': 52.99,
                       'population_density_miles': 137.24,
                       'population_density_ranking': 154,
                       'population_ranking': 117},
               'ESP': {'alpha2': 'ES',
                       'alpha3': 'ESP',
                       'area_km': 498980,
                       'area_miles': 192657,
                       'area_ranking': 52,
                       'capital': 'Madrid',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/9/9a/Flag_of_Spain.svg/1920px-Flag_of_Spain.svg.png',
                       'gdp': 1393490000000,
                       'gdp_per_capita': 30007,
                       'gdp_per_capita_ranking': 58,
                       'gdp_ranking': 13,
                       'largest_city': 'Madrid',
                       'name': 'Spain',
                       'official_name': 'Kingdom of Spain',
                       'population': 46438422,
                       'population_density_km': 93.07,
                       'population_density_miles': 241.04,
                       'population_density_ranking': 115,
                       'population_ranking': 30},
               'EST': {'alpha2': 'EE',
                       'alpha3': 'EST',
                       'area_km': 42388,
                       'area_miles': 16367,
                       'area_ranking': 134,
                       'capital': 'Tallinn',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/8f/Flag_of_Estonia.svg/1920px-Flag_of_Estonia.svg.png',
                       'gdp': 31471000000,
                       'gdp_per_capita': 23915,
                       'gdp_per_capita_ranking': 70,
                       'gdp_ranking': 103,
                       'largest_city': 'Tallinn',
                       'name': 'Estonia',
                       'official_name': 'Republic of Estonia',
                       'population': 1315944,
                       'population_density_km': 31.05,
                       'population_density_miles': 80.4,
                       'population_density_ranking': 185,
                       'population_ranking': 153},
               'ETH': {'alpha2': 'ET',
                       'alpha3': 'ETH',
                       'area_km': 1000000,
                       'area_miles': 386101,
                       'area_ranking': 29,
                       'capital': 'Addis Ababa',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/71/Flag_of_Ethiopia.svg/1280px-Flag_of_Ethiopia.svg.png',
                       'gdp': 92750000000,
                       'gdp_per_capita': 1005,
                       'gdp_per_capita_ranking': 218,
                       'gdp_ranking': 67,
                       'largest_city': 'Addis Ababa',
                       'name': 'Ethiopia',
                       'official_name': 'Federal Democratic Republic of Ethiopia',
                       'population': 92206005,
                       'population_density_km': 92.21,
                       'population_density_miles': 238.81,
                       'population_density_ranking': 117,
                       'population_ranking': 14},
               'FIN': {'alpha2': 'FI',
                       'alpha3': 'FIN',
                       'area_km': 303815,
                       'area_miles': 117304,
                       'area_ranking': 71,
                       'capital': 'Helsinki',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/bc/Flag_of_Finland.svg/1920px-Flag_of_Finland.svg.png',
                       'gdp': 269296000000,
                       'gdp_per_capita': 49035,
                       'gdp_per_capita_ranking': 29,
                       'gdp_ranking': 44,
                       'largest_city': 'Helsinki',
                       'name': 'Finland',
                       'official_name': 'Republic of Finland',
                       'population': 5491817,
                       'population_density_km': 18.08,
                       'population_density_miles': 46.82,
                       'population_density_ranking': 201,
                       'population_ranking': 115},
               'FJI': {'alpha2': 'FJ',
                       'alpha3': 'FJI',
                       'area_km': 18274,
                       'area_miles': 7056,
                       'area_ranking': 157,
                       'capital': 'Suva',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/ba/Flag_of_Fiji.svg/1920px-Flag_of_Fiji.svg.png',
                       'gdp': 5504000000,
                       'gdp_per_capita': 6348,
                       'gdp_per_capita_ranking': 143,
                       'gdp_ranking': 168,
                       'largest_city': 'Suva',
                       'name': 'Fiji',
                       'official_name': 'Republic of Fiji',
                       'population': 867000,
                       'population_density_km': 47.44,
                       'population_density_miles': 122.87,
                       'population_density_ranking': 163,
                       'population_ranking': 160},
               'FLK': {'alpha2': 'FK',
                       'alpha3': 'FLK',
                       'area_km': 12173,
                       'area_miles': 4700,
                       'area_ranking': 163,
                       'capital': 'Stanley',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/83/Flag_of_the_Falkland_Islands.svg/2880px-Flag_of_the_Falkland_Islands.svg.png',
                       'gdp': 193280000,
                       'gdp_per_capita': 75411,
                       'gdp_per_capita_ranking': 12,
                       'gdp_ranking': 228,
                       'largest_city': 'Stanley',
                       'name': 'Falkland Islands',
                       'population': 2563,
                       'population_density_km': 0.21,
                       'population_density_miles': 0.55,
                       'population_density_ranking': 240,
                       'population_ranking': 235},
               'FRA': {'alpha2': 'FR',
                       'alpha3': 'FRA',
                       'area_km': 543940,
                       'area_miles': 210016,
                       'area_ranking': 49,
                       'capital': 'Paris',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/c/c3/Flag_of_France.svg/1024px-Flag_of_France.svg.png',
                       'gdp': 2715518000000,
                       'gdp_per_capita': 40706,
                       'gdp_per_capita_ranking': 42,
                       'gdp_ranking': 7,
                       'largest_city': 'Paris',
                       'name': 'France',
                       'official_name': 'French Republic',
                       'population': 66710000,
                       'population_density_km': 122.64,
                       'population_density_miles': 317.64,
                       'population_density_ranking': 94,
                       'population_ranking': 20},
               'FRO': {'alpha2': 'FO',
                       'alpha3': 'FRO',
                       'area_km': 1399,
                       'area_miles': 541,
                       'area_ranking': 185,
                       'capital': 'Tórshavn',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/3c/Flag_of_the_Faroe_Islands.svg/1920px-Flag_of_the_Faroe_Islands.svg.png',
                       'gdp': 3126000000,
                       'gdp_per_capita': 63310,
                       'gdp_per_capita_ranking': 19,
                       'gdp_ranking': 182,
                       'largest_city': 'Tórshavn',
                       'name': 'Faroe Islands',
                       'population': 49376,
                       'population_density_km': 35.29,
                       'population_density_miles': 91.27,
                       'population_density_ranking': 179,
                       'population_ranking': 212},
               'FSM': {'alpha2': 'FM',
                       'alpha3': 'FSM',
                       'area_km': 702,
                       'area_miles': 272,
                       'area_ranking': 194,
                       'capital': 'Palikir',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/e4/Flag_of_the_Federated_States_of_Micronesia.svg/2560px-Flag_of_the_Federated_States_of_Micronesia.svg.png',
                       'gdp': 414000000,
                       'gdp_per_capita': 4027,
                       'gdp_per_capita_ranking': 168,
                       'gdp_ranking': 220,
                       'largest_city': 'Weno',
                       'name': 'Micronesia',
                       'official_name': 'Federated States of Micronesia',
                       'population': 102800,
                       'population_density_km': 146.44,
                       'population_density_miles': 377.94,
                       'population_density_ranking': 82,
                       'population_ranking': 197},
               'GAB': {'alpha2': 'GA',
                       'alpha3': 'GAB',
                       'area_km': 257667,
                       'area_miles': 99486,
                       'area_ranking': 76,
                       'capital': 'Libreville',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/04/Flag_of_Gabon.svg/1280px-Flag_of_Gabon.svg.png',
                       'gdp': 16887000000,
                       'gdp_per_capita': 9369,
                       'gdp_per_capita_ranking': 124,
                       'gdp_ranking': 125,
                       'largest_city': 'Libreville',
                       'name': 'Gabon',
                       'official_name': 'Gabonese Republic',
                       'population': 1802278,
                       'population_density_km': 6.99,
                       'population_density_miles': 18.12,
                       'population_density_ranking': 224,
                       'population_ranking': 149},
               'GBR': {'alpha2': 'GB',
                       'alpha3': 'GBR',
                       'area_km': 242495,
                       'area_miles': 93628,
                       'area_ranking': 79,
                       'capital': 'London',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/a/ae/Flag_of_the_United_Kingdom.svg/2560px-Flag_of_the_United_Kingdom.svg.png',
                       'gdp': 2826441000000,
                       'gdp_per_capita': 43410,
                       'gdp_per_capita_ranking': 38,
                       'gdp_ranking': 6,
                       'largest_city': 'London',
                       'name': 'United Kingdom',
                       'official_name': 'United Kingdom of Great Britain and Northern '
                                        'Ireland',
                       'population': 65110000,
                       'population_density_km': 268.5,
                       'population_density_miles': 695.41,
                       'population_density_ranking': 52,
                       'population_ranking': 22},
               'GEO': {'alpha2': 'GE',
                       'alpha3': 'GEO',
                       'area_km': 69700,
                       'area_miles': 26912,
                       'area_ranking': 120,
                       'capital': 'Tbilisi',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/0f/Flag_of_Georgia.svg/1280px-Flag_of_Georgia.svg.png',
                       'gdp': 17742000000,
                       'gdp_per_capita': 4768,
                       'gdp_per_capita_ranking': 156,
                       'gdp_ranking': 122,
                       'largest_city': 'Tbilisi',
                       'name': 'Georgia',
                       'population': 3720400,
                       'population_density_km': 53.38,
                       'population_density_miles': 138.24,
                       'population_density_ranking': 153,
                       'population_ranking': 130},
               'GGY': {'alpha2': 'GG',
                       'alpha3': 'GGY',
                       'area_km': 65,
                       'area_miles': 26,
                       'area_ranking': 231,
                       'capital': 'St. Peter Port',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fa/Flag_of_Guernsey.svg/1920px-Flag_of_Guernsey.svg.png',
                       'gdp': 4469000000,
                       'gdp_per_capita': 70937,
                       'gdp_per_capita_ranking': 14,
                       'gdp_ranking': 174,
                       'largest_city': 'Saint Peter Port',
                       'name': 'Guernsey',
                       'population': 62999,
                       'population_density_km': 969.22,
                       'population_density_miles': 2423.04,
                       'population_density_ranking': 13,
                       'population_ranking': 204},
               'GHA': {'alpha2': 'GH',
                       'alpha3': 'GHA',
                       'area_km': 227533,
                       'area_miles': 87851,
                       'area_ranking': 82,
                       'capital': 'Accra',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/19/Flag_of_Ghana.svg/1280px-Flag_of_Ghana.svg.png',
                       'gdp': 66999000000,
                       'gdp_per_capita': 2421,
                       'gdp_per_capita_ranking': 192,
                       'gdp_ranking': 76,
                       'largest_city': 'Accra',
                       'name': 'Ghana',
                       'official_name': 'Republic of Ghana',
                       'population': 27670174,
                       'population_density_km': 121.61,
                       'population_density_miles': 314.97,
                       'population_density_ranking': 95,
                       'population_ranking': 45},
               'GIB': {'alpha2': 'GI',
                       'alpha3': 'GIB',
                       'area_km': 7,
                       'area_miles': 3,
                       'area_ranking': 244,
                       'capital': 'Gibraltar',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/02/Flag_of_Gibraltar.svg/2560px-Flag_of_Gibraltar.svg.png',
                       'gdp': 3221550302,
                       'gdp_per_capita': 97210,
                       'gdp_per_capita_ranking': 7,
                       'gdp_ranking': 179,
                       'largest_city': 'Westside',
                       'name': 'Gibraltar',
                       'population': 33140,
                       'population_density_km': 4734.29,
                       'population_density_miles': 11046.67,
                       'population_density_ranking': 5,
                       'population_ranking': 218},
               'GIN': {'alpha2': 'GN',
                       'alpha3': 'GIN',
                       'area_km': 245717,
                       'area_miles': 94872,
                       'area_ranking': 78,
                       'capital': 'Malabo',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/ed/Flag_of_Guinea.svg/1280px-Flag_of_Guinea.svg.png',
                       'gdp': 12354000000,
                       'gdp_per_capita': 10106,
                       'gdp_per_capita_ranking': 119,
                       'gdp_ranking': 144,
                       'largest_city': 'Conakry',
                       'name': 'Guinea',
                       'official_name': 'Republic of Guinea',
                       'population': 1222442,
                       'population_density_km': 4.97,
                       'population_density_miles': 12.89,
                       'population_density_ranking': 227,
                       'population_ranking': 155},
               'GLP': {'alpha2': 'GP',
                       'alpha3': 'GLP',
                       'area_km': 1628,
                       'area_miles': 629,
                       'area_ranking': 183,
                       'capital': 'Basse-Terre',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/c/c3/Flag_of_France.svg/1920px-Flag_of_France.svg.png',
                       'gdp': 10000000000,
                       'gdp_per_capita': 24991,
                       'gdp_per_capita_ranking': 68,
                       'gdp_ranking': 150,
                       'largest_city': 'Pointe-à-Pitre',
                       'name': 'Guadeloupe',
                       'population': 400132,
                       'population_density_km': 245.78,
                       'population_density_miles': 636.14,
                       'population_density_ranking': 55,
                       'population_ranking': 175},
               'GMB': {'alpha2': 'GM',
                       'alpha3': 'GMB',
                       'area_km': 10000,
                       'area_miles': 3862,
                       'area_ranking': 169,
                       'capital': 'Banjul',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/77/Flag_of_The_Gambia.svg/1920px-Flag_of_The_Gambia.svg.png',
                       'gdp': 1822000000,
                       'gdp_per_capita': 967,
                       'gdp_per_capita_ranking': 220,
                       'gdp_ranking': 196,
                       'largest_city': 'Banjul',
                       'name': 'Gambia',
                       'official_name': 'Republic of the Gambia',
                       'population': 1882450,
                       'population_density_km': 188.25,
                       'population_density_miles': 487.43,
                       'population_density_ranking': 72,
                       'population_ranking': 148},
               'GNB': {'alpha2': 'GW',
                       'alpha3': 'GNB',
                       'area_km': 28120,
                       'area_miles': 10858,
                       'area_ranking': 143,
                       'capital': 'Bissau',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/01/Flag_of_Guinea-Bissau.svg/1920px-Flag_of_Guinea-Bissau.svg.png',
                       'gdp': 1322000000,
                       'gdp_per_capita': 854,
                       'gdp_per_capita_ranking': 225,
                       'gdp_ranking': 202,
                       'largest_city': 'Bissau',
                       'name': 'Guinea-Bissau',
                       'official_name': 'Republic of Guinea-Bissau',
                       'population': 1547777,
                       'population_density_km': 55.04,
                       'population_density_miles': 142.55,
                       'population_density_ranking': 151,
                       'population_ranking': 150},
               'GNQ': {'alpha2': 'GQ',
                       'alpha3': 'GNQ',
                       'area_km': 28051,
                       'area_miles': 10831,
                       'area_ranking': 144,
                       'capital': 'Malabo',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/31/Flag_of_Equatorial_Guinea.svg/1280px-Flag_of_Equatorial_Guinea.svg.png',
                       'gdp': 11024000000,
                       'gdp_per_capita': 9018,
                       'gdp_per_capita_ranking': 125,
                       'gdp_ranking': 148,
                       'largest_city': 'Bata',
                       'name': 'Equatorial Guinea',
                       'official_name': 'Republic of Equatorial Guinea',
                       'population': 1222442,
                       'population_density_km': 43.58,
                       'population_density_miles': 112.87,
                       'population_density_ranking': 169,
                       'population_ranking': 156},
               'GRC': {'alpha2': 'GR',
                       'alpha3': 'GRC',
                       'area_km': 130647,
                       'area_miles': 50443,
                       'area_ranking': 95,
                       'capital': 'Athens',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/5c/Flag_of_Greece.svg/1280px-Flag_of_Greece.svg.png',
                       'gdp': 205326000000,
                       'gdp_per_capita': 18910,
                       'gdp_per_capita_ranking': 84,
                       'gdp_ranking': 53,
                       'largest_city': 'Athens',
                       'name': 'Greece',
                       'official_name': 'Hellenic Republic',
                       'population': 10858018,
                       'population_density_km': 83.11,
                       'population_density_miles': 215.25,
                       'population_density_ranking': 123,
                       'population_ranking': 82},
               'GRD': {'alpha2': 'GD',
                       'alpha3': 'GRD',
                       'area_km': 344,
                       'area_miles': 133,
                       'area_ranking': 210,
                       'capital': "St. George's",
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/bc/Flag_of_Grenada.svg/1920px-Flag_of_Grenada.svg.png',
                       'gdp': 1211000000,
                       'gdp_per_capita': 11719,
                       'gdp_per_capita_ranking': 108,
                       'gdp_ranking': 205,
                       'largest_city': "St. George's",
                       'name': 'Grenada',
                       'population': 103328,
                       'population_density_km': 300.37,
                       'population_density_miles': 776.9,
                       'population_density_ranking': 48,
                       'population_ranking': 195},
               'GRL': {'alpha2': 'GL',
                       'alpha3': 'GRL',
                       'area_km': 2166086,
                       'area_miles': 836327,
                       'area_ranking': 12,
                       'capital': 'Nuuk',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/09/Flag_of_Greenland.svg/1920px-Flag_of_Greenland.svg.png',
                       'gdp': 3023000000,
                       'gdp_per_capita': 54130,
                       'gdp_per_capita_ranking': 23,
                       'gdp_ranking': 185,
                       'largest_city': 'Nuuk',
                       'name': 'Greenland',
                       'population': 55847,
                       'population_density_km': 0.03,
                       'population_density_miles': 0.07,
                       'population_density_ranking': 243,
                       'population_ranking': 210},
               'GTM': {'alpha2': 'GT',
                       'alpha3': 'GTM',
                       'area_km': 107159,
                       'area_miles': 41375,
                       'area_ranking': 103,
                       'capital': 'Guatemala City',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/ec/Flag_of_Guatemala.svg/1920px-Flag_of_Guatemala.svg.png',
                       'gdp': 76710000000,
                       'gdp_per_capita': 4742,
                       'gdp_per_capita_ranking': 157,
                       'gdp_ranking': 72,
                       'largest_city': 'Guatemala City',
                       'name': 'Guatemala',
                       'official_name': 'Republic of Guatemala',
                       'population': 16176133,
                       'population_density_km': 150.95,
                       'population_density_miles': 390.96,
                       'population_density_ranking': 78,
                       'population_ranking': 67},
               'GUF': {'alpha2': 'GF',
                       'alpha3': 'GUF',
                       'area_km': 83534,
                       'area_miles': 32253,
                       'area_ranking': 115,
                       'capital': 'Cayenne',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/29/Flag_of_French_Guiana.svg/1280px-Flag_of_French_Guiana.svg.png',
                       'gdp': 4870000000,
                       'gdp_per_capita': 19132,
                       'gdp_per_capita_ranking': 82,
                       'gdp_ranking': 172,
                       'largest_city': 'Cayenne',
                       'name': 'French Guiana',
                       'population': 254541,
                       'population_density_km': 3.05,
                       'population_density_miles': 7.89,
                       'population_density_ranking': 236,
                       'population_ranking': 185},
               'GUM': {'alpha2': 'GU',
                       'alpha3': 'GUM',
                       'area_km': 540,
                       'area_miles': 209,
                       'area_ranking': 198,
                       'capital': 'Hagåtña',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/07/Flag_of_Guam.svg/2560px-Flag_of_Guam.svg.png',
                       'gdp': 6311000000,
                       'gdp_per_capita': 34261,
                       'gdp_per_capita_ranking': 50,
                       'gdp_ranking': 163,
                       'largest_city': 'Dededo',
                       'name': 'Guam',
                       'population': 184200,
                       'population_density_km': 341.11,
                       'population_density_miles': 881.34,
                       'population_density_ranking': 40,
                       'population_ranking': 189},
               'GUY': {'alpha2': 'GY',
                       'alpha3': 'GUY',
                       'area_km': 196849,
                       'area_miles': 76004,
                       'area_ranking': 85,
                       'capital': 'Georgetown',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/99/Flag_of_Guyana.svg/1920px-Flag_of_Guyana.svg.png',
                       'gdp': 5173000000,
                       'gdp_per_capita': 6925,
                       'gdp_per_capita_ranking': 136,
                       'gdp_ranking': 170,
                       'largest_city': 'Georgetown',
                       'name': 'Guyana',
                       'official_name': 'Republic of Guyana',
                       'population': 746900,
                       'population_density_km': 3.79,
                       'population_density_miles': 9.83,
                       'population_density_ranking': 229,
                       'population_ranking': 165},
               'HKG': {'alpha2': 'HK',
                       'alpha3': 'HKG',
                       'area_km': 1106,
                       'area_miles': 428,
                       'area_ranking': 187,
                       'capital': 'City of Victoria',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/5b/Flag_of_Hong_Kong.svg/1920px-Flag_of_Hong_Kong.svg.png',
                       'gdp': 365710000000,
                       'gdp_per_capita': 49931,
                       'gdp_per_capita_ranking': 28,
                       'gdp_ranking': 34,
                       'largest_city': 'Hong Kong',
                       'name': 'Hong Kong',
                       'official_name': 'Hong Kong Special Administrative Region of China',
                       'population': 7324300,
                       'population_density_km': 6622.33,
                       'population_density_miles': 17112.85,
                       'population_density_ranking': 3,
                       'population_ranking': 100},
               'HMD': {'alpha2': 'HM',
                       'alpha3': 'HMD',
                       'area_km': 368,
                       'area_miles': 143,
                       'area_ranking': 208,
                       'capital': None,
                       'continent': 'ANTARCTICA',
                       'flag_url': None,
                       'gdp': 0,
                       'gdp_per_capita': 0,
                       'gdp_per_capita_ranking': 244,
                       'gdp_ranking': 244,
                       'largest_city': None,
                       'name': 'Heard Island and McDonald Islands',
                       'population': 0,
                       'population_density_km': 0.0,
                       'population_density_miles': 0.0,
                       'population_density_ranking': 246,
                       'population_ranking': 248},
               'HND': {'alpha2': 'HN',
                       'alpha3': 'HND',
                       'area_km': 111890,
                       'area_miles': 43201,
                       'area_ranking': 100,
                       'capital': 'Tegucigalpa',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/82/Flag_of_Honduras.svg/1920px-Flag_of_Honduras.svg.png',
                       'gdp': 25095000000,
                       'gdp_per_capita': 2926,
                       'gdp_per_capita_ranking': 184,
                       'gdp_ranking': 107,
                       'largest_city': 'Tegucigalpa',
                       'name': 'Honduras',
                       'official_name': 'Republic of Honduras',
                       'population': 8576532,
                       'population_density_km': 76.65,
                       'population_density_miles': 198.53,
                       'population_density_ranking': 132,
                       'population_ranking': 96},
               'HRV': {'alpha2': 'HR',
                       'alpha3': 'HRV',
                       'area_km': 55974,
                       'area_miles': 21612,
                       'area_ranking': 126,
                       'capital': 'Zagreb',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/1b/Flag_of_Croatia.svg/1024px-Flag_of_Croatia.svg.png',
                       'gdp': 60415000000,
                       'gdp_per_capita': 14416,
                       'gdp_per_capita_ranking': 100,
                       'gdp_ranking': 81,
                       'largest_city': 'Zagreb',
                       'name': 'Croatia',
                       'official_name': 'Republic of Croatia',
                       'population': 4190669,
                       'population_density_km': 74.87,
                       'population_density_miles': 193.9,
                       'population_density_ranking': 134,
                       'population_ranking': 127},
               'HTI': {'alpha2': 'HT',
                       'alpha3': 'HTI',
                       'area_km': 27560,
                       'area_miles': 10641,
                       'area_ranking': 146,
                       'capital': 'Port-au-Prince',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/56/Flag_of_Haiti.svg/1920px-Flag_of_Haiti.svg.png',
                       'gdp': 8051000000,
                       'gdp_per_capita': 726,
                       'gdp_per_capita_ranking': 228,
                       'gdp_ranking': 155,
                       'largest_city': 'Port-au-Prince',
                       'name': 'Haiti',
                       'official_name': 'Republic of Haiti',
                       'population': 11078033,
                       'population_density_km': 401.96,
                       'population_density_miles': 1041.07,
                       'population_density_ranking': 32,
                       'population_ranking': 80},
               'HUN': {'alpha2': 'HU',
                       'alpha3': 'HUN',
                       'area_km': 89608,
                       'area_miles': 34598,
                       'area_ranking': 110,
                       'capital': 'Budapest',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/c1/Flag_of_Hungary.svg/1920px-Flag_of_Hungary.svg.png',
                       'gdp': 163469000000,
                       'gdp_per_capita': 16641,
                       'gdp_per_capita_ranking': 91,
                       'gdp_ranking': 57,
                       'largest_city': 'Budapest',
                       'name': 'Hungary',
                       'official_name': 'Hungary',
                       'population': 9823000,
                       'population_density_km': 109.62,
                       'population_density_miles': 283.92,
                       'population_density_ranking': 100,
                       'population_ranking': 90},
               'IDN': {'alpha2': 'ID',
                       'alpha3': 'IDN',
                       'area_km': 1811569,
                       'area_miles': 699448,
                       'area_ranking': 15,
                       'capital': 'Jakarta',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9f/Flag_of_Indonesia.svg/1920px-Flag_of_Indonesia.svg.png',
                       'gdp': 1119190000000,
                       'gdp_per_capita': 4326,
                       'gdp_per_capita_ranking': 163,
                       'gdp_ranking': 16,
                       'largest_city': 'Jakarta',
                       'name': 'Indonesia',
                       'official_name': 'Republic of Indonesia',
                       'population': 258705000,
                       'population_density_km': 142.81,
                       'population_density_miles': 369.87,
                       'population_density_ranking': 84,
                       'population_ranking': 4},
               'IMN': {'alpha2': 'IM',
                       'alpha3': 'IMN',
                       'area_km': 572,
                       'area_miles': 221,
                       'area_ranking': 197,
                       'capital': 'Douglas',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/bc/Flag_of_the_Isle_of_Man.svg/2560px-Flag_of_the_Isle_of_Man.svg.png',
                       'gdp': 7492000000,
                       'gdp_per_capita': 88665,
                       'gdp_per_capita_ranking': 8,
                       'gdp_ranking': 157,
                       'largest_city': 'Douglas',
                       'name': 'Isle of Man',
                       'population': 84497,
                       'population_density_km': 147.72,
                       'population_density_miles': 382.34,
                       'population_density_ranking': 80,
                       'population_ranking': 201},
               'IND': {'alpha2': 'IN',
                       'alpha3': 'IND',
                       'area_km': 2973190,
                       'area_miles': 1147950,
                       'area_ranking': 7,
                       'capital': 'New Delhi',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/4/41/Flag_of_India.svg/1280px-Flag_of_India.svg.png',
                       'gdp': 2891582000000,
                       'gdp_per_capita': 2116,
                       'gdp_per_capita_ranking': 194,
                       'gdp_ranking': 5,
                       'largest_city': 'Mumbai',
                       'name': 'India',
                       'official_name': 'Republic of India',
                       'population': 1366000000,
                       'population_density_km': 459.44,
                       'population_density_miles': 1189.95,
                       'population_density_ranking': 27,
                       'population_ranking': 2},
               'IOT': {'alpha2': 'IO',
                       'alpha3': 'IOT',
                       'area_km': 54400,
                       'area_miles': 21004,
                       'area_ranking': 127,
                       'capital': 'Diego Garcia',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/65/Flag_of_the_Commissioner_of_the_British_Indian_Ocean_Territory.svg/2560px-Flag_of_the_Commissioner_of_the_British_Indian_Ocean_Territory.svg.png',
                       'gdp': 0,
                       'gdp_per_capita': 0,
                       'gdp_per_capita_ranking': 245,
                       'gdp_ranking': 245,
                       'largest_city': 'Diego Garcia',
                       'name': 'British Indian Ocean Territory',
                       'population': 3000,
                       'population_density_km': 0.06,
                       'population_density_miles': 0.14,
                       'population_density_ranking': 241,
                       'population_ranking': 234},
               'IRL': {'alpha2': 'IE',
                       'alpha3': 'IRL',
                       'area_km': 68883,
                       'area_miles': 26596,
                       'area_ranking': 121,
                       'capital': 'Dublin',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/45/Flag_of_Ireland.svg/1920px-Flag_of_Ireland.svg.png',
                       'gdp': 398590000000,
                       'gdp_per_capita': 62494,
                       'gdp_per_capita_ranking': 20,
                       'gdp_ranking': 31,
                       'largest_city': 'Dublin',
                       'name': 'Ireland',
                       'population': 6378000,
                       'population_density_km': 92.59,
                       'population_density_miles': 239.81,
                       'population_density_ranking': 116,
                       'population_ranking': 109},
               'IRN': {'alpha2': 'IR',
                       'alpha3': 'IRN',
                       'area_km': 1531595,
                       'area_miles': 591350,
                       'area_ranking': 19,
                       'capital': 'Tehran',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/ca/Flag_of_Iran.svg/1920px-Flag_of_Iran.svg.png',
                       'gdp': 603779000000,
                       'gdp_per_capita': 7607,
                       'gdp_per_capita_ranking': 132,
                       'gdp_ranking': 21,
                       'largest_city': 'Tehran',
                       'name': 'Iran',
                       'official_name': 'Islamic Republic of Iran',
                       'population': 79369900,
                       'population_density_km': 51.82,
                       'population_density_miles': 134.22,
                       'population_density_ranking': 157,
                       'population_ranking': 18},
               'IRQ': {'alpha2': 'IQ',
                       'alpha3': 'IRQ',
                       'area_km': 437367,
                       'area_miles': 168868,
                       'area_ranking': 57,
                       'capital': 'Baghdad',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/f6/Flag_of_Iraq.svg/1280px-Flag_of_Iraq.svg.png',
                       'gdp': 225232000000,
                       'gdp_per_capita': 5945,
                       'gdp_per_capita_ranking': 146,
                       'gdp_ranking': 51,
                       'largest_city': 'Baghdad',
                       'name': 'Iraq',
                       'official_name': 'Republic of Iraq',
                       'population': 37883543,
                       'population_density_km': 86.62,
                       'population_density_miles': 224.34,
                       'population_density_ranking': 121,
                       'population_ranking': 35},
               'ISL': {'alpha2': 'IS',
                       'alpha3': 'ISL',
                       'area_km': 100250,
                       'area_miles': 38707,
                       'area_ranking': 105,
                       'capital': 'Reykjavík',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/ce/Flag_of_Iceland.svg/1280px-Flag_of_Iceland.svg.png',
                       'gdp': 24188000000,
                       'gdp_per_capita': 72354,
                       'gdp_per_capita_ranking': 13,
                       'gdp_ranking': 111,
                       'largest_city': 'Reykjavík',
                       'name': 'Iceland',
                       'official_name': 'Republic of Iceland',
                       'population': 334300,
                       'population_density_km': 3.33,
                       'population_density_miles': 8.64,
                       'population_density_ranking': 234,
                       'population_ranking': 180},
               'ISR': {'alpha2': 'IL',
                       'alpha3': 'ISR',
                       'area_km': 20330,
                       'area_miles': 7850,
                       'area_ranking': 154,
                       'capital': 'Jerusalem (Disputed)',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d4/Flag_of_Israel.svg/1280px-Flag_of_Israel.svg.png',
                       'gdp': 395098000000,
                       'gdp_per_capita': 46332,
                       'gdp_per_capita_ranking': 35,
                       'gdp_ranking': 32,
                       'largest_city': 'Jerusalem (Disputed)',
                       'name': 'Israel',
                       'official_name': 'State of Israel',
                       'population': 8527400,
                       'population_density_km': 419.45,
                       'population_density_miles': 1086.29,
                       'population_density_ranking': 30,
                       'population_ranking': 97},
               'ITA': {'alpha2': 'IT',
                       'alpha3': 'ITA',
                       'area_km': 294140,
                       'area_miles': 113568,
                       'area_ranking': 73,
                       'capital': 'Rome',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/0/03/Flag_of_Italy.svg/1280px-Flag_of_Italy.svg.png',
                       'gdp': 2003576000000,
                       'gdp_per_capita': 33026,
                       'gdp_per_capita_ranking': 52,
                       'gdp_ranking': 8,
                       'largest_city': 'Rome',
                       'name': 'Italy',
                       'official_name': 'Italian Republic',
                       'population': 60665551,
                       'population_density_km': 206.25,
                       'population_density_miles': 534.18,
                       'population_density_ranking': 66,
                       'population_ranking': 23},
               'JAM': {'alpha2': 'JM',
                       'alpha3': 'JAM',
                       'area_km': 10831,
                       'area_miles': 4182,
                       'area_ranking': 166,
                       'capital': 'Kingston',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/0a/Flag_of_Jamaica.svg/1920px-Flag_of_Jamaica.svg.png',
                       'gdp': 15830000000,
                       'gdp_per_capita': 5812,
                       'gdp_per_capita_ranking': 147,
                       'gdp_ranking': 128,
                       'largest_city': 'Kingston',
                       'name': 'Jamaica',
                       'population': 2723246,
                       'population_density_km': 251.43,
                       'population_density_miles': 651.18,
                       'population_density_ranking': 54,
                       'population_ranking': 140},
               'JEY': {'alpha2': 'JE',
                       'alpha3': 'JEY',
                       'area_km': 118,
                       'area_miles': 46,
                       'area_ranking': 227,
                       'capital': 'Saint Helier',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/1c/Flag_of_Jersey.svg/2560px-Flag_of_Jersey.svg.png',
                       'gdp': 6630000000,
                       'gdp_per_capita': 65773,
                       'gdp_per_capita_ranking': 18,
                       'gdp_ranking': 162,
                       'largest_city': 'Saint Helier',
                       'name': 'Jersey',
                       'population': 100800,
                       'population_density_km': 854.24,
                       'population_density_miles': 2191.3,
                       'population_density_ranking': 14,
                       'population_ranking': 198},
               'JOR': {'alpha2': 'JO',
                       'alpha3': 'JOR',
                       'area_km': 88802,
                       'area_miles': 34287,
                       'area_ranking': 111,
                       'capital': 'Amman',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/c0/Flag_of_Jordan.svg/1920px-Flag_of_Jordan.svg.png',
                       'gdp': 44502000000,
                       'gdp_per_capita': 4668,
                       'gdp_per_capita_ranking': 158,
                       'gdp_ranking': 93,
                       'largest_city': 'Amman',
                       'name': 'Jordan',
                       'official_name': 'Hashemite Kingdom of Jordan',
                       'population': 9531712,
                       'population_density_km': 107.34,
                       'population_density_miles': 278.0,
                       'population_density_ranking': 102,
                       'population_ranking': 92},
               'JPN': {'alpha2': 'JP',
                       'alpha3': 'JPN',
                       'area_km': 364546,
                       'area_miles': 140752,
                       'area_ranking': 63,
                       'capital': 'Tokyo',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/9/9e/Flag_of_Japan.svg/1920px-Flag_of_Japan.svg.png',
                       'gdp': 5082465000000,
                       'gdp_per_capita': 40032,
                       'gdp_per_capita_ranking': 44,
                       'gdp_ranking': 3,
                       'largest_city': 'Tokyo',
                       'name': 'Japan',
                       'population': 126960000,
                       'population_density_km': 348.27,
                       'population_density_miles': 902.01,
                       'population_density_ranking': 38,
                       'population_ranking': 10},
               'KAZ': {'alpha2': 'KZ',
                       'alpha3': 'KAZ',
                       'area_km': 2699700,
                       'area_miles': 1042356,
                       'area_ranking': 9,
                       'capital': 'Astana',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d3/Flag_of_Kazakhstan.svg/1920px-Flag_of_Kazakhstan.svg.png',
                       'gdp': 181667000000,
                       'gdp_per_capita': 10232,
                       'gdp_per_capita_ranking': 117,
                       'gdp_ranking': 55,
                       'largest_city': 'Almaty',
                       'name': 'Kazakhstan',
                       'official_name': 'Republic of Kazakhstan',
                       'population': 17753200,
                       'population_density_km': 6.58,
                       'population_density_miles': 17.03,
                       'population_density_ranking': 225,
                       'population_ranking': 63},
               'KEN': {'alpha2': 'KE',
                       'alpha3': 'KEN',
                       'area_km': 569140,
                       'area_miles': 219746,
                       'area_ranking': 47,
                       'capital': 'Nairobi',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/49/Flag_of_Kenya.svg/1920px-Flag_of_Kenya.svg.png',
                       'gdp': 95501000000,
                       'gdp_per_capita': 2021,
                       'gdp_per_capita_ranking': 197,
                       'gdp_ranking': 66,
                       'largest_city': 'Nairobi',
                       'name': 'Kenya',
                       'official_name': 'Republic of Kenya',
                       'population': 47251000,
                       'population_density_km': 83.02,
                       'population_density_miles': 215.03,
                       'population_density_ranking': 124,
                       'population_ranking': 29},
               'KGZ': {'alpha2': 'KG',
                       'alpha3': 'KGZ',
                       'area_km': 191801,
                       'area_miles': 74055,
                       'area_ranking': 87,
                       'capital': 'Bishkek',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/c4/Flag_of_Kyrgyzstan_%28official_standards%29.png/1920px-Flag_of_Kyrgyzstan_%28official_standards%29.png',
                       'gdp': 8454000000,
                       'gdp_per_capita': 1397,
                       'gdp_per_capita_ranking': 210,
                       'gdp_ranking': 152,
                       'largest_city': 'Bishkek',
                       'name': 'Kyrgyzstan',
                       'official_name': 'Kyrgyz Republic',
                       'population': 6047800,
                       'population_density_km': 31.53,
                       'population_density_miles': 81.67,
                       'population_density_ranking': 183,
                       'population_ranking': 111},
               'KHM': {'alpha2': 'KH',
                       'alpha3': 'KHM',
                       'area_km': 176515,
                       'area_miles': 68153,
                       'area_ranking': 89,
                       'capital': 'Phnom Penh',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/83/Flag_of_Cambodia.svg/1024px-Flag_of_Cambodia.svg.png',
                       'gdp': 27097000000,
                       'gdp_per_capita': 1734,
                       'gdp_per_capita_ranking': 201,
                       'gdp_ranking': 105,
                       'largest_city': 'Phnom Penh',
                       'name': 'Cambodia',
                       'official_name': 'Kingdom of Cambodia',
                       'population': 15626444,
                       'population_density_km': 88.53,
                       'population_density_miles': 229.28,
                       'population_density_ranking': 120,
                       'population_ranking': 69},
               'KIR': {'alpha2': 'KI',
                       'alpha3': 'KIR',
                       'area_km': 811,
                       'area_miles': 314,
                       'area_ranking': 189,
                       'capital': 'South Tarawa',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d3/Flag_of_Kiribati.svg/1920px-Flag_of_Kiribati.svg.png',
                       'gdp': 194000000,
                       'gdp_per_capita': 1710,
                       'gdp_per_capita_ranking': 204,
                       'gdp_ranking': 227,
                       'largest_city': 'South Tarawa',
                       'name': 'Kiribati',
                       'official_name': 'Republic of Kiribati',
                       'population': 113400,
                       'population_density_km': 139.83,
                       'population_density_miles': 361.15,
                       'population_density_ranking': 86,
                       'population_ranking': 192},
               'KNA': {'alpha2': 'KN',
                       'alpha3': 'KNA',
                       'area_km': 261,
                       'area_miles': 101,
                       'area_ranking': 215,
                       'capital': 'Basseterre',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fe/Flag_of_Saint_Kitts_and_Nevis.svg/1920px-Flag_of_Saint_Kitts_and_Nevis.svg.png',
                       'gdp': 1050000000,
                       'gdp_per_capita': 22725,
                       'gdp_per_capita_ranking': 73,
                       'gdp_ranking': 209,
                       'largest_city': 'Basseterre',
                       'name': 'Saint Kitts and Nevis',
                       'population': 46204,
                       'population_density_km': 177.03,
                       'population_density_miles': 457.47,
                       'population_density_ranking': 75,
                       'population_ranking': 213},
               'KOR': {'alpha2': 'KR',
                       'alpha3': 'KOR',
                       'area_km': 99909,
                       'area_miles': 38575,
                       'area_ranking': 106,
                       'capital': 'Seoul',
                       'continent': 'VOID',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/09/Flag_of_South_Korea.svg/1280px-Flag_of_South_Korea.svg.png',
                       'gdp': 1646539000000,
                       'gdp_per_capita': 32411,
                       'gdp_per_capita_ranking': 54,
                       'gdp_ranking': 12,
                       'largest_city': 'Seoul',
                       'name': 'South Korea',
                       'population': 50801405,
                       'population_density_km': 508.48,
                       'population_density_miles': 1316.95,
                       'population_density_ranking': 23,
                       'population_ranking': 27},
               'KWT': {'alpha2': 'KW',
                       'alpha3': 'KWT',
                       'area_km': 17818,
                       'area_miles': 6880,
                       'area_ranking': 158,
                       'capital': 'Kuwait City',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/a/aa/Flag_of_Kuwait.svg/1920px-Flag_of_Kuwait.svg.png',
                       'gdp': 134623000000,
                       'gdp_per_capita': 32178,
                       'gdp_per_capita_ranking': 55,
                       'gdp_ranking': 60,
                       'largest_city': 'Kuwait City',
                       'name': 'Kuwait',
                       'official_name': 'State of Kuwait',
                       'population': 4183658,
                       'population_density_km': 234.8,
                       'population_density_miles': 608.09,
                       'population_density_ranking': 57,
                       'population_ranking': 128},
               'LAO': {'alpha2': 'LA',
                       'alpha3': 'LAO',
                       'area_km': 230800,
                       'area_miles': 89112,
                       'area_ranking': 81,
                       'capital': 'Vientiane',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/56/Flag_of_Laos.svg/1920px-Flag_of_Laos.svg.png',
                       'gdp': 18822000000,
                       'gdp_per_capita': 2899,
                       'gdp_per_capita_ranking': 185,
                       'gdp_ranking': 119,
                       'largest_city': 'Vientiane',
                       'name': 'Laos',
                       'population': 6492400,
                       'population_density_km': 28.13,
                       'population_density_miles': 72.86,
                       'population_density_ranking': 186,
                       'population_ranking': 107},
               'LBN': {'alpha2': 'LB',
                       'alpha3': 'LBN',
                       'area_km': 10230,
                       'area_miles': 3950,
                       'area_ranking': 167,
                       'capital': 'Beirut',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/59/Flag_of_Lebanon.svg/1920px-Flag_of_Lebanon.svg.png',
                       'gdp': 56409000000,
                       'gdp_per_capita': 9420,
                       'gdp_per_capita_ranking': 122,
                       'gdp_ranking': 84,
                       'largest_city': 'Beirut',
                       'name': 'Lebanon',
                       'official_name': 'Lebanese Republic',
                       'population': 5988000,
                       'population_density_km': 585.34,
                       'population_density_miles': 1515.95,
                       'population_density_ranking': 20,
                       'population_ranking': 112},
               'LBR': {'alpha2': 'LR',
                       'alpha3': 'LBR',
                       'area_km': 96320,
                       'area_miles': 37190,
                       'area_ranking': 107,
                       'capital': 'Monrovia',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b8/Flag_of_Liberia.svg/1920px-Flag_of_Liberia.svg.png',
                       'gdp': 2582000000,
                       'gdp_per_capita': 559,
                       'gdp_per_capita_ranking': 235,
                       'gdp_ranking': 187,
                       'largest_city': 'Monrovia',
                       'name': 'Liberia',
                       'official_name': 'Republic of Liberia',
                       'population': 4615000,
                       'population_density_km': 47.91,
                       'population_density_miles': 124.09,
                       'population_density_ranking': 162,
                       'population_ranking': 125},
               'LBY': {'alpha2': 'LY',
                       'alpha3': 'LBY',
                       'area_km': 1759540,
                       'area_miles': 679360,
                       'area_ranking': 16,
                       'capital': 'Tripoli',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/05/Flag_of_Libya.svg/1920px-Flag_of_Libya.svg.png',
                       'gdp': 32600000000,
                       'gdp_per_capita': 5105,
                       'gdp_per_capita_ranking': 153,
                       'gdp_ranking': 102,
                       'largest_city': 'Tripoli',
                       'name': 'Libya',
                       'official_name': 'Libya',
                       'population': 6385000,
                       'population_density_km': 3.63,
                       'population_density_miles': 9.4,
                       'population_density_ranking': 231,
                       'population_ranking': 108},
               'LCA': {'alpha2': 'LC',
                       'alpha3': 'LCA',
                       'area_km': 606,
                       'area_miles': 234,
                       'area_ranking': 196,
                       'capital': 'Castries',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9f/Flag_of_Saint_Lucia.svg/1920px-Flag_of_Saint_Lucia.svg.png',
                       'gdp': 2122000000,
                       'gdp_per_capita': 11408,
                       'gdp_per_capita_ranking': 111,
                       'gdp_ranking': 191,
                       'largest_city': 'Castries',
                       'name': 'Saint Lucia',
                       'population': 186000,
                       'population_density_km': 306.93,
                       'population_density_miles': 794.87,
                       'population_density_ranking': 46,
                       'population_ranking': 188},
               'LIE': {'alpha2': 'LI',
                       'alpha3': 'LIE',
                       'area_km': 160,
                       'area_miles': 62,
                       'area_ranking': 222,
                       'capital': 'Vaduz',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/47/Flag_of_Liechtenstein.svg/1920px-Flag_of_Liechtenstein.svg.png',
                       'gdp': 6797000000,
                       'gdp_per_capita': 180660,
                       'gdp_per_capita_ranking': 2,
                       'gdp_ranking': 161,
                       'largest_city': 'Schaan',
                       'name': 'Liechtenstein',
                       'official_name': 'Principality of Liechtenstein',
                       'population': 37623,
                       'population_density_km': 235.14,
                       'population_density_miles': 606.82,
                       'population_density_ranking': 56,
                       'population_ranking': 216},
               'LKA': {'alpha2': 'LK',
                       'alpha3': 'LKA',
                       'area_km': 62732,
                       'area_miles': 24221,
                       'area_ranking': 122,
                       'capital': 'Colombo',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/11/Flag_of_Sri_Lanka.svg/1920px-Flag_of_Sri_Lanka.svg.png',
                       'gdp': 84008000000,
                       'gdp_per_capita': 4006,
                       'gdp_per_capita_ranking': 169,
                       'gdp_ranking': 70,
                       'largest_city': 'Colombo',
                       'name': 'Sri Lanka',
                       'official_name': 'Democratic Socialist Republic of Sri Lanka',
                       'population': 20966000,
                       'population_density_km': 334.22,
                       'population_density_miles': 865.61,
                       'population_density_ranking': 43,
                       'population_ranking': 56},
               'LSO': {'alpha2': 'LS',
                       'alpha3': 'LSO',
                       'area_km': 30355,
                       'area_miles': 11721,
                       'area_ranking': 140,
                       'capital': 'Maseru',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/4a/Flag_of_Lesotho.svg/1920px-Flag_of_Lesotho.svg.png',
                       'gdp': 2460000000,
                       'gdp_per_capita': 1298,
                       'gdp_per_capita_ranking': 213,
                       'gdp_ranking': 189,
                       'largest_city': 'Maseru',
                       'name': 'Lesotho',
                       'official_name': 'Kingdom of Lesotho',
                       'population': 1894194,
                       'population_density_km': 62.4,
                       'population_density_miles': 161.61,
                       'population_density_ranking': 148,
                       'population_ranking': 147},
               'LTU': {'alpha2': 'LT',
                       'alpha3': 'LTU',
                       'area_km': 62680,
                       'area_miles': 24201,
                       'area_ranking': 123,
                       'capital': 'Vilnius',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/11/Flag_of_Lithuania.svg/1920px-Flag_of_Lithuania.svg.png',
                       'gdp': 54627000000,
                       'gdp_per_capita': 19018,
                       'gdp_per_capita_ranking': 83,
                       'gdp_ranking': 86,
                       'largest_city': 'Vilnius',
                       'name': 'Lithuania',
                       'official_name': 'Republic of Lithuania',
                       'population': 2872294,
                       'population_density_km': 45.82,
                       'population_density_miles': 118.68,
                       'population_density_ranking': 168,
                       'population_ranking': 139},
               'LUX': {'alpha2': 'LU',
                       'alpha3': 'LUX',
                       'area_km': 2586,
                       'area_miles': 999,
                       'area_ranking': 179,
                       'capital': 'Luxembourg City',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/da/Flag_of_Luxembourg.svg/1920px-Flag_of_Luxembourg.svg.png',
                       'gdp': 71104000000,
                       'gdp_per_capita': 123401,
                       'gdp_per_capita_ranking': 3,
                       'gdp_ranking': 74,
                       'largest_city': 'Luxembourg City',
                       'name': 'Luxembourg',
                       'official_name': 'Grand Duchy of Luxembourg',
                       'population': 576200,
                       'population_density_km': 222.82,
                       'population_density_miles': 576.78,
                       'population_density_ranking': 59,
                       'population_ranking': 169},
               'LVA': {'alpha2': 'LV',
                       'alpha3': 'LVA',
                       'area_km': 62249,
                       'area_miles': 24035,
                       'area_ranking': 124,
                       'capital': 'Riga',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/84/Flag_of_Latvia.svg/1920px-Flag_of_Latvia.svg.png',
                       'gdp': 34102000000,
                       'gdp_per_capita': 17384,
                       'gdp_per_capita_ranking': 88,
                       'gdp_ranking': 100,
                       'largest_city': 'Riga',
                       'name': 'Latvia',
                       'official_name': 'Republic of Latvia',
                       'population': 1961600,
                       'population_density_km': 31.51,
                       'population_density_miles': 81.61,
                       'population_density_ranking': 184,
                       'population_ranking': 146},
               'MAC': {'alpha2': 'MO',
                       'alpha3': 'MAC',
                       'area_km': 115,
                       'area_miles': 45,
                       'area_ranking': 228,
                       'capital': 'Macao',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/63/Flag_of_Macau.svg/1920px-Flag_of_Macau.svg.png',
                       'gdp': 53859000000,
                       'gdp_per_capita': 82974,
                       'gdp_per_capita_ranking': 10,
                       'gdp_ranking': 88,
                       'largest_city': 'Macao',
                       'name': 'Macao',
                       'official_name': 'Macao Special Administrative Region of China',
                       'population': 649100,
                       'population_density_km': 5644.35,
                       'population_density_miles': 14424.44,
                       'population_density_ranking': 4,
                       'population_ranking': 166},
               'MAF': {'alpha2': 'MF',
                       'alpha3': 'MAF',
                       'area_km': 25,
                       'area_miles': 10,
                       'area_ranking': 240,
                       'capital': 'Marigot',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/c/c3/Flag_of_France.svg/1920px-Flag_of_France.svg.png',
                       'gdp': 599000000,
                       'gdp_per_capita': 16198,
                       'gdp_per_capita_ranking': 93,
                       'gdp_ranking': 215,
                       'largest_city': 'Marigot',
                       'name': 'Saint Martin',
                       'population': 36979,
                       'population_density_km': 1479.16,
                       'population_density_miles': 3697.9,
                       'population_density_ranking': 7,
                       'population_ranking': 217},
               'MAR': {'alpha2': 'MA',
                       'alpha3': 'MAR',
                       'area_km': 446300,
                       'area_miles': 172317,
                       'area_ranking': 56,
                       'capital': 'Rabat',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/2c/Flag_of_Morocco.svg/1920px-Flag_of_Morocco.svg.png',
                       'gdp': 119700000000,
                       'gdp_per_capita': 3590,
                       'gdp_per_capita_ranking': 174,
                       'gdp_ranking': 61,
                       'largest_city': 'Casablanca',
                       'name': 'Morocco',
                       'official_name': 'Kingdom of Morocco',
                       'population': 33337529,
                       'population_density_km': 74.7,
                       'population_density_miles': 193.47,
                       'population_density_ranking': 135,
                       'population_ranking': 38},
               'MCO': {'alpha2': 'MC',
                       'alpha3': 'MCO',
                       'area_km': 2,
                       'area_miles': 1,
                       'area_ranking': 245,
                       'capital': 'Monte Carlo',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/ea/Flag_of_Monaco.svg/1920px-Flag_of_Monaco.svg.png',
                       'gdp': 7423000000,
                       'gdp_per_capita': 193307,
                       'gdp_per_capita_ranking': 1,
                       'gdp_ranking': 158,
                       'largest_city': 'Larvotto',
                       'name': 'Monaco',
                       'official_name': 'Principality of Monaco',
                       'population': 38400,
                       'population_density_km': 19200.0,
                       'population_density_miles': 38400.0,
                       'population_density_ranking': 1,
                       'population_ranking': 214},
               'MDA': {'alpha2': 'MD',
                       'alpha3': 'MDA',
                       'area_km': 32891,
                       'area_miles': 12700,
                       'area_ranking': 138,
                       'capital': 'Chișinău',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/27/Flag_of_Moldova.svg/2560px-Flag_of_Moldova.svg.png',
                       'gdp': 11955000000,
                       'gdp_per_capita': 3364,
                       'gdp_per_capita_ranking': 179,
                       'gdp_ranking': 145,
                       'largest_city': 'Chișinău',
                       'name': 'Moldova',
                       'official_name': 'Republic of Moldova',
                       'population': 3553100,
                       'population_density_km': 108.03,
                       'population_density_miles': 279.77,
                       'population_density_ranking': 101,
                       'population_ranking': 132},
               'MDG': {'alpha2': 'MG',
                       'alpha3': 'MDG',
                       'area_km': 581540,
                       'area_miles': 224533,
                       'area_ranking': 45,
                       'capital': 'Antananarivo',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/bc/Flag_of_Madagascar.svg/1920px-Flag_of_Madagascar.svg.png',
                       'gdp': 14104000000,
                       'gdp_per_capita': 628,
                       'gdp_per_capita_ranking': 231,
                       'gdp_ranking': 134,
                       'largest_city': 'Antananarivo',
                       'name': 'Madagascar',
                       'official_name': 'Republic of Madagascar',
                       'population': 22434363,
                       'population_density_km': 38.58,
                       'population_density_miles': 99.92,
                       'population_density_ranking': 174,
                       'population_ranking': 55},
               'MDV': {'alpha2': 'MV',
                       'alpha3': 'MDV',
                       'area_km': 298,
                       'area_miles': 116,
                       'area_ranking': 213,
                       'capital': 'Malé',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/0f/Flag_of_Maldives.svg/1920px-Flag_of_Maldives.svg.png',
                       'gdp': 5642000000,
                       'gdp_per_capita': 16400,
                       'gdp_per_capita_ranking': 92,
                       'gdp_ranking': 166,
                       'largest_city': 'Malé',
                       'name': 'Maldives',
                       'official_name': 'Republic of Maldives',
                       'population': 344023,
                       'population_density_km': 1154.44,
                       'population_density_miles': 2965.72,
                       'population_density_ranking': 11,
                       'population_ranking': 179},
               'MEX': {'alpha2': 'MX',
                       'alpha3': 'MEX',
                       'area_km': 1943945,
                       'area_miles': 750558,
                       'area_ranking': 14,
                       'capital': 'Mexico City',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fc/Flag_of_Mexico.svg/2560px-Flag_of_Mexico.svg.png',
                       'gdp': 1256440000000,
                       'gdp_per_capita': 10275,
                       'gdp_per_capita_ranking': 116,
                       'gdp_ranking': 15,
                       'largest_city': 'Mexico City',
                       'name': 'Mexico',
                       'official_name': 'United Mexican States',
                       'population': 122273473,
                       'population_density_km': 62.9,
                       'population_density_miles': 162.91,
                       'population_density_ranking': 147,
                       'population_ranking': 11},
               'MHL': {'alpha2': 'MH',
                       'alpha3': 'MHL',
                       'area_km': 181,
                       'area_miles': 70,
                       'area_ranking': 221,
                       'capital': 'Majuro',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/2e/Flag_of_the_Marshall_Islands.svg/1920px-Flag_of_the_Marshall_Islands.svg.png',
                       'gdp': 237000000,
                       'gdp_per_capita': 4318,
                       'gdp_per_capita_ranking': 164,
                       'gdp_ranking': 226,
                       'largest_city': 'Majuro',
                       'name': 'Marshall Islands',
                       'official_name': 'Republic of the Marshall Islands',
                       'population': 54880,
                       'population_density_km': 303.2,
                       'population_density_miles': 784.0,
                       'population_density_ranking': 47,
                       'population_ranking': 211},
               'MKD': {'alpha2': 'MK',
                       'alpha3': 'MKD',
                       'area_km': 25433,
                       'area_miles': 9820,
                       'area_ranking': 149,
                       'capital': 'Skopje',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/79/Flag_of_North_Macedonia.svg/2560px-Flag_of_North_Macedonia.svg.png',
                       'gdp': 12694000000,
                       'gdp_per_capita': 6166,
                       'gdp_per_capita_ranking': 145,
                       'gdp_ranking': 140,
                       'largest_city': 'Skopje',
                       'name': 'North Macedonia',
                       'official_name': 'Republic of North Macedonia',
                       'population': 2058539,
                       'population_density_km': 80.94,
                       'population_density_miles': 209.63,
                       'population_density_ranking': 126,
                       'population_ranking': 145},
               'MLI': {'alpha2': 'ML',
                       'alpha3': 'MLI',
                       'area_km': 1220190,
                       'area_miles': 471116,
                       'area_ranking': 24,
                       'capital': 'Bamako',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/92/Flag_of_Mali.svg/1920px-Flag_of_Mali.svg.png',
                       'gdp': 17432000000,
                       'gdp_per_capita': 961,
                       'gdp_per_capita_ranking': 222,
                       'gdp_ranking': 123,
                       'largest_city': 'Bamako',
                       'name': 'Mali',
                       'official_name': 'Republic of Mali',
                       'population': 18135000,
                       'population_density_km': 14.86,
                       'population_density_miles': 38.49,
                       'population_density_ranking': 212,
                       'population_ranking': 62},
               'MLT': {'alpha2': 'MT',
                       'alpha3': 'MLT',
                       'area_km': 316,
                       'area_miles': 123,
                       'area_ranking': 212,
                       'capital': 'Valletta',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/73/Flag_of_Malta.svg/1920px-Flag_of_Malta.svg.png',
                       'gdp': 14863000000,
                       'gdp_per_capita': 34940,
                       'gdp_per_capita_ranking': 48,
                       'gdp_ranking': 131,
                       'largest_city': "St. Paul's Bay",
                       'name': 'Malta',
                       'official_name': 'Republic of Malta',
                       'population': 425384,
                       'population_density_km': 1346.15,
                       'population_density_miles': 3458.41,
                       'population_density_ranking': 8,
                       'population_ranking': 173},
               'MMR': {'alpha2': 'MM',
                       'alpha3': 'MMR',
                       'area_km': 653508,
                       'area_miles': 252320,
                       'area_ranking': 40,
                       'capital': 'Naypyidaw',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/8c/Flag_of_Myanmar.svg/1920px-Flag_of_Myanmar.svg.png',
                       'gdp': 76784000000,
                       'gdp_per_capita': 1493,
                       'gdp_per_capita_ranking': 207,
                       'gdp_ranking': 71,
                       'largest_city': 'Yangon',
                       'name': 'Myanmar',
                       'official_name': 'Republic of Myanmar',
                       'population': 51419420,
                       'population_density_km': 78.68,
                       'population_density_miles': 203.79,
                       'population_density_ranking': 128,
                       'population_ranking': 26},
               'MNE': {'alpha2': 'ME',
                       'alpha3': 'MNE',
                       'area_km': 13452,
                       'area_miles': 5194,
                       'area_ranking': 161,
                       'capital': 'Podgorica',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/64/Flag_of_Montenegro.svg/2560px-Flag_of_Montenegro.svg.png',
                       'gdp': 5542000000,
                       'gdp_per_capita': 8912,
                       'gdp_per_capita_ranking': 127,
                       'gdp_ranking': 167,
                       'largest_city': 'Podgorica',
                       'name': 'Montenegro',
                       'official_name': 'Montenegro',
                       'population': 621810,
                       'population_density_km': 46.22,
                       'population_density_miles': 119.72,
                       'population_density_ranking': 166,
                       'population_ranking': 168},
               'MNG': {'alpha2': 'MN',
                       'alpha3': 'MNG',
                       'area_km': 1553556,
                       'area_miles': 599829,
                       'area_ranking': 18,
                       'capital': 'Ulaanbaatar',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/4c/Flag_of_Mongolia.svg/2560px-Flag_of_Mongolia.svg.png',
                       'gdp': 13852000000,
                       'gdp_per_capita': 4478,
                       'gdp_per_capita_ranking': 160,
                       'gdp_ranking': 135,
                       'largest_city': 'Ulaanbaatar',
                       'name': 'Mongolia',
                       'population': 3093100,
                       'population_density_km': 1.99,
                       'population_density_miles': 5.16,
                       'population_density_ranking': 238,
                       'population_ranking': 136},
               'MNP': {'alpha2': 'MP',
                       'alpha3': 'MNP',
                       'area_km': 464,
                       'area_miles': 180,
                       'area_ranking': 200,
                       'capital': 'Saipan',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/e0/Flag_of_the_Northern_Mariana_Islands.svg/2560px-Flag_of_the_Northern_Mariana_Islands.svg.png',
                       'gdp': 1182000000,
                       'gdp_per_capita': 20758,
                       'gdp_per_capita_ranking': 76,
                       'gdp_ranking': 207,
                       'largest_city': 'Saipan',
                       'name': 'Northern Mariana Islands',
                       'official_name': 'Commonwealth of the Northern Mariana Islands',
                       'population': 56940,
                       'population_density_km': 122.72,
                       'population_density_miles': 316.33,
                       'population_density_ranking': 93,
                       'population_ranking': 209},
               'MOZ': {'alpha2': 'MZ',
                       'alpha3': 'MOZ',
                       'area_km': 786380,
                       'area_miles': 303622,
                       'area_ranking': 36,
                       'capital': 'Maputo',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d0/Flag_of_Mozambique.svg/1920px-Flag_of_Mozambique.svg.png',
                       'gdp': 15296000000,
                       'gdp_per_capita': 578,
                       'gdp_per_capita_ranking': 234,
                       'gdp_ranking': 129,
                       'largest_city': 'Maputo',
                       'name': 'Mozambique',
                       'official_name': 'Republic of Mozambique',
                       'population': 26423700,
                       'population_density_km': 33.6,
                       'population_density_miles': 87.03,
                       'population_density_ranking': 182,
                       'population_ranking': 48},
               'MRT': {'alpha2': 'MR',
                       'alpha3': 'MRT',
                       'area_km': 1025520,
                       'area_miles': 395954,
                       'area_ranking': 28,
                       'capital': 'Nouakchott',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/43/Flag_of_Mauritania.svg/1920px-Flag_of_Mauritania.svg.png',
                       'gdp': 7593000000,
                       'gdp_per_capita': 2041,
                       'gdp_per_capita_ranking': 195,
                       'gdp_ranking': 156,
                       'largest_city': 'Nouakchott',
                       'name': 'Mauritania',
                       'official_name': 'Islamic Republic of Mauritania',
                       'population': 3718678,
                       'population_density_km': 3.63,
                       'population_density_miles': 9.39,
                       'population_density_ranking': 232,
                       'population_ranking': 131},
               'MSR': {'alpha2': 'MS',
                       'alpha3': 'MSR',
                       'area_km': 102,
                       'area_miles': 40,
                       'area_ranking': 229,
                       'capital': 'Plymouth',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d0/Flag_of_Montserrat.svg/2560px-Flag_of_Montserrat.svg.png',
                       'gdp': 67000000,
                       'gdp_per_capita': 13612,
                       'gdp_per_capita_ranking': 101,
                       'gdp_ranking': 232,
                       'largest_city': 'Brades',
                       'name': 'Montserrat',
                       'population': 4922,
                       'population_density_km': 48.25,
                       'population_density_miles': 123.05,
                       'population_density_ranking': 160,
                       'population_ranking': 232},
               'MTQ': {'alpha2': 'MQ',
                       'alpha3': 'MTQ',
                       'area_km': 1128,
                       'area_miles': 436,
                       'area_ranking': 186,
                       'capital': 'Fort-de-France',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/64/Snake_Flag_of_Martinique.svg/1920px-Snake_Flag_of_Martinique.svg.png',
                       'gdp': 11314000000,
                       'gdp_per_capita': 29911,
                       'gdp_per_capita_ranking': 59,
                       'gdp_ranking': 146,
                       'largest_city': 'Fort-de-France',
                       'name': 'Martinique',
                       'population': 378243,
                       'population_density_km': 335.32,
                       'population_density_miles': 867.53,
                       'population_density_ranking': 41,
                       'population_ranking': 176},
               'MUS': {'alpha2': 'MU',
                       'alpha3': 'MUS',
                       'area_km': 2030,
                       'area_miles': 784,
                       'area_ranking': 181,
                       'capital': 'Port Louis',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/77/Flag_of_Mauritius.svg/1920px-Flag_of_Mauritius.svg.png',
                       'gdp': 14180000000,
                       'gdp_per_capita': 11228,
                       'gdp_per_capita_ranking': 112,
                       'gdp_ranking': 133,
                       'largest_city': 'Port Louis',
                       'name': 'Mauritius',
                       'official_name': 'Republic of Mauritius',
                       'population': 1262879,
                       'population_density_km': 622.11,
                       'population_density_miles': 1610.82,
                       'population_density_ranking': 18,
                       'population_ranking': 154},
               'MWI': {'alpha2': 'MW',
                       'alpha3': 'MWI',
                       'area_km': 94080,
                       'area_miles': 36325,
                       'area_ranking': 108,
                       'capital': 'Lilongwe',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d1/Flag_of_Malawi.svg/1920px-Flag_of_Malawi.svg.png',
                       'gdp': 8099000000,
                       'gdp_per_capita': 481,
                       'gdp_per_capita_ranking': 237,
                       'gdp_ranking': 154,
                       'largest_city': 'Lilongwe',
                       'name': 'Malawi',
                       'official_name': 'Republic of Malawi',
                       'population': 16832910,
                       'population_density_km': 178.92,
                       'population_density_miles': 463.4,
                       'population_density_ranking': 74,
                       'population_ranking': 65},
               'MYS': {'alpha2': 'MY',
                       'alpha3': 'MYS',
                       'area_km': 329613,
                       'area_miles': 127264,
                       'area_ranking': 66,
                       'capital': 'Kuala Lumpur',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/66/Flag_of_Malaysia.svg/1920px-Flag_of_Malaysia.svg.png',
                       'gdp': 364684000000,
                       'gdp_per_capita': 11612,
                       'gdp_per_capita_ranking': 109,
                       'gdp_ranking': 35,
                       'largest_city': 'Kuala Lumpur',
                       'name': 'Malaysia',
                       'population': 31405416,
                       'population_density_km': 95.28,
                       'population_density_miles': 246.77,
                       'population_density_ranking': 112,
                       'population_ranking': 42},
               'MYT': {'alpha2': 'YT',
                       'alpha3': 'MYT',
                       'area_km': 374,
                       'area_miles': 145,
                       'area_ranking': 207,
                       'capital': 'Mamoudzou',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/c/c3/Flag_of_France.svg/1920px-Flag_of_France.svg.png',
                       'gdp': 3049992000,
                       'gdp_per_capita': 13441,
                       'gdp_per_capita_ranking': 102,
                       'gdp_ranking': 184,
                       'largest_city': 'Mamoudzou',
                       'name': 'Mayotte',
                       'population': 226915,
                       'population_density_km': 606.72,
                       'population_density_miles': 1564.93,
                       'population_density_ranking': 19,
                       'population_ranking': 186},
               'NAM': {'alpha2': 'NA',
                       'alpha3': 'NAM',
                       'area_km': 823290,
                       'area_miles': 317873,
                       'area_ranking': 35,
                       'capital': 'Windhoek',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/00/Flag_of_Namibia.svg/1920px-Flag_of_Namibia.svg.png',
                       'gdp': 12366000000,
                       'gdp_per_capita': 5320,
                       'gdp_per_capita_ranking': 150,
                       'gdp_ranking': 143,
                       'largest_city': 'Ho Chi Minh City',
                       'name': 'Namibia',
                       'official_name': 'Republic of Namibia',
                       'population': 2324388,
                       'population_density_km': 2.82,
                       'population_density_miles': 7.31,
                       'population_density_ranking': 237,
                       'population_ranking': 142},
               'NCL': {'alpha2': 'NC',
                       'alpha3': 'NCL',
                       'area_km': 18576,
                       'area_miles': 7173,
                       'area_ranking': 156,
                       'capital': 'Nouméa',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/66/Flag_of_FLNKS.svg/2560px-Flag_of_FLNKS.svg.png',
                       'gdp': 9879000000,
                       'gdp_per_capita': 36756,
                       'gdp_per_capita_ranking': 46,
                       'gdp_ranking': 151,
                       'largest_city': 'Nouméa',
                       'name': 'New Caledonia',
                       'population': 268767,
                       'population_density_km': 14.47,
                       'population_density_miles': 37.47,
                       'population_density_ranking': 213,
                       'population_ranking': 184},
               'NER': {'alpha2': 'NE',
                       'alpha3': 'NER',
                       'area_km': 1266700,
                       'area_miles': 489074,
                       'area_ranking': 21,
                       'capital': 'Niamey',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/f4/Flag_of_Niger.svg/1920px-Flag_of_Niger.svg.png',
                       'gdp': 12927000000,
                       'gdp_per_capita': 624,
                       'gdp_per_capita_ranking': 232,
                       'gdp_ranking': 139,
                       'largest_city': 'Niamey',
                       'name': 'Niger',
                       'official_name': 'Republic of the Niger',
                       'population': 20715000,
                       'population_density_km': 16.35,
                       'population_density_miles': 42.36,
                       'population_density_ranking': 207,
                       'population_ranking': 57},
               'NFK': {'alpha2': 'NF',
                       'alpha3': 'NFK',
                       'area_km': 35,
                       'area_miles': 14,
                       'area_ranking': 235,
                       'capital': 'Kingston',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/48/Flag_of_Norfolk_Island.svg/2560px-Flag_of_Norfolk_Island.svg.png',
                       'gdp': 60200000,
                       'gdp_per_capita': 26151,
                       'gdp_per_capita_ranking': 66,
                       'gdp_ranking': 233,
                       'largest_city': 'Burnt Pine',
                       'name': 'Norfolk Island',
                       'population': 2302,
                       'population_density_km': 65.77,
                       'population_density_miles': 164.43,
                       'population_density_ranking': 144,
                       'population_ranking': 237},
               'NGA': {'alpha2': 'NG',
                       'alpha3': 'NGA',
                       'area_km': 910768,
                       'area_miles': 351648,
                       'area_ranking': 31,
                       'capital': 'Abuja',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/79/Flag_of_Nigeria.svg/2560px-Flag_of_Nigeria.svg.png',
                       'gdp': 474516000000,
                       'gdp_per_capita': 2537,
                       'gdp_per_capita_ranking': 191,
                       'gdp_ranking': 26,
                       'largest_city': 'Lagos',
                       'name': 'Nigeria',
                       'official_name': 'Federal Republic of Nigeria',
                       'population': 186988000,
                       'population_density_km': 205.31,
                       'population_density_miles': 531.75,
                       'population_density_ranking': 67,
                       'population_ranking': 7},
               'NIC': {'alpha2': 'NI',
                       'alpha3': 'NIC',
                       'area_km': 119990,
                       'area_miles': 46329,
                       'area_ranking': 98,
                       'capital': 'Managua',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/19/Flag_of_Nicaragua.svg/2560px-Flag_of_Nicaragua.svg.png',
                       'gdp': 12520000000,
                       'gdp_per_capita': 1999,
                       'gdp_per_capita_ranking': 198,
                       'gdp_ranking': 141,
                       'largest_city': 'Managua',
                       'name': 'Nicaragua',
                       'official_name': 'Republic of Nicaragua',
                       'population': 6262703,
                       'population_density_km': 52.19,
                       'population_density_miles': 135.18,
                       'population_density_ranking': 155,
                       'population_ranking': 110},
               'NIU': {'alpha2': 'NU',
                       'alpha3': 'NIU',
                       'area_km': 261,
                       'area_miles': 101,
                       'area_ranking': 216,
                       'capital': 'Alofi',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/01/Flag_of_Niue.svg/2560px-Flag_of_Niue.svg.png',
                       'gdp': 10000000,
                       'gdp_per_capita': 6802,
                       'gdp_per_capita_ranking': 138,
                       'gdp_ranking': 240,
                       'largest_city': 'Alofi',
                       'name': 'Niue',
                       'official_name': 'Niue',
                       'population': 1470,
                       'population_density_km': 5.63,
                       'population_density_miles': 14.55,
                       'population_density_ranking': 226,
                       'population_ranking': 239},
               'NLD': {'alpha2': 'NL',
                       'alpha3': 'NLD',
                       'area_km': 33893,
                       'area_miles': 13087,
                       'area_ranking': 137,
                       'capital': 'Amsterdam',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/20/Flag_of_the_Netherlands.svg/1920px-Flag_of_the_Netherlands.svg.png',
                       'gdp': 907050000000,
                       'gdp_per_capita': 53293,
                       'gdp_per_capita_ranking': 25,
                       'gdp_ranking': 17,
                       'largest_city': 'Amsterdam',
                       'name': 'Netherlands',
                       'official_name': 'Kingdom of the Netherlands',
                       'population': 17019800,
                       'population_density_km': 502.16,
                       'population_density_miles': 1300.51,
                       'population_density_ranking': 24,
                       'population_ranking': 64},
               'NOR': {'alpha2': 'NO',
                       'alpha3': 'NOR',
                       'area_km': 365957,
                       'area_miles': 141297,
                       'area_ranking': 62,
                       'capital': 'Oslo',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d9/Flag_of_Norway.svg/1920px-Flag_of_Norway.svg.png',
                       'gdp': 403336000000,
                       'gdp_per_capita': 77219,
                       'gdp_per_capita_ranking': 11,
                       'gdp_ranking': 30,
                       'largest_city': 'Oslo',
                       'name': 'Norway',
                       'official_name': 'Kingdom of Norway',
                       'population': 5223256,
                       'population_density_km': 14.27,
                       'population_density_miles': 36.97,
                       'population_density_ranking': 215,
                       'population_ranking': 118},
               'NPL': {'alpha2': 'NP',
                       'alpha3': 'NPL',
                       'area_km': 143351,
                       'area_miles': 55348,
                       'area_ranking': 93,
                       'capital': 'Kathmandu',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9b/Flag_of_Nepal.svg/1024px-Flag_of_Nepal.svg.png',
                       'gdp': 30714000000,
                       'gdp_per_capita': 1080,
                       'gdp_per_capita_ranking': 216,
                       'gdp_ranking': 104,
                       'largest_city': 'Kathmandu',
                       'name': 'Nepal',
                       'official_name': 'Federal Democratic Republic of Nepal',
                       'population': 28431500,
                       'population_density_km': 198.33,
                       'population_density_miles': 513.69,
                       'population_density_ranking': 69,
                       'population_ranking': 44},
               'NRU': {'alpha2': 'NR',
                       'alpha3': 'NRU',
                       'area_km': 21,
                       'area_miles': 9,
                       'area_ranking': 241,
                       'capital': 'Yaren',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/30/Flag_of_Nauru.svg/2560px-Flag_of_Nauru.svg.png',
                       'gdp': 132000000,
                       'gdp_per_capita': 13090,
                       'gdp_per_capita_ranking': 104,
                       'gdp_ranking': 231,
                       'largest_city': 'Denigomodu District',
                       'name': 'Nauru',
                       'official_name': 'Republic of Nauru',
                       'population': 10084,
                       'population_density_km': 480.19,
                       'population_density_miles': 1120.44,
                       'population_density_ranking': 25,
                       'population_ranking': 229},
               'NZL': {'alpha2': 'NZ',
                       'alpha3': 'NZL',
                       'area_km': 262443,
                       'area_miles': 101330,
                       'area_ranking': 75,
                       'capital': 'Wellington',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Flag_of_New_Zealand.svg/1920px-Flag_of_New_Zealand.svg.png',
                       'gdp': 206936000000,
                       'gdp_per_capita': 44049,
                       'gdp_per_capita_ranking': 37,
                       'gdp_ranking': 52,
                       'largest_city': 'Auckland',
                       'name': 'New Zealand',
                       'population': 4697854,
                       'population_density_km': 17.9,
                       'population_density_miles': 46.36,
                       'population_density_ranking': 202,
                       'population_ranking': 123},
               'OMN': {'alpha2': 'OM',
                       'alpha3': 'OMN',
                       'area_km': 309500,
                       'area_miles': 119499,
                       'area_ranking': 70,
                       'capital': 'Muscat',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/dd/Flag_of_Oman.svg/2560px-Flag_of_Oman.svg.png',
                       'gdp': 76331000000,
                       'gdp_per_capita': 17268,
                       'gdp_per_capita_ranking': 89,
                       'gdp_ranking': 73,
                       'largest_city': 'Muscat',
                       'name': 'Oman',
                       'official_name': 'Sultanate of Oman',
                       'population': 4420133,
                       'population_density_km': 14.28,
                       'population_density_miles': 36.99,
                       'population_density_ranking': 214,
                       'population_ranking': 126},
               'PAK': {'alpha2': 'PK',
                       'alpha3': 'PAK',
                       'area_km': 882623,
                       'area_miles': 340782,
                       'area_ranking': 33,
                       'capital': 'Islamabad',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/32/Flag_of_Pakistan.svg/1920px-Flag_of_Pakistan.svg.png',
                       'gdp': 263000000000,
                       'gdp_per_capita': 1354,
                       'gdp_per_capita_ranking': 211,
                       'gdp_ranking': 45,
                       'largest_city': 'Karachi',
                       'name': 'Pakistan',
                       'official_name': 'Islamic Republic of Pakistan',
                       'population': 194125062,
                       'population_density_km': 219.94,
                       'population_density_miles': 569.65,
                       'population_density_ranking': 61,
                       'population_ranking': 6},
               'PAN': {'alpha2': 'PA',
                       'alpha3': 'PAN',
                       'area_km': 74340,
                       'area_miles': 28703,
                       'area_ranking': 118,
                       'capital': 'Panama City',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/a/ab/Flag_of_Panama.svg/1920px-Flag_of_Panama.svg.png',
                       'gdp': 66787000000,
                       'gdp_per_capita': 17507,
                       'gdp_per_capita_ranking': 87,
                       'gdp_ranking': 77,
                       'largest_city': 'Panama City',
                       'name': 'Panama',
                       'official_name': 'Republic of Panama',
                       'population': 3814672,
                       'population_density_km': 51.31,
                       'population_density_miles': 132.9,
                       'population_density_ranking': 158,
                       'population_ranking': 129},
               'PCN': {'alpha2': 'PN',
                       'alpha3': 'PCN',
                       'area_km': 47,
                       'area_miles': 19,
                       'area_ranking': 234,
                       'capital': 'Adamstown',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/88/Flag_of_the_Pitcairn_Islands.svg/2560px-Flag_of_the_Pitcairn_Islands.svg.png',
                       'gdp': 154352,
                       'gdp_per_capita': 2756,
                       'gdp_per_capita_ranking': 188,
                       'gdp_ranking': 242,
                       'largest_city': 'Adamstown',
                       'name': 'Pitcairn',
                       'population': 56,
                       'population_density_km': 1.19,
                       'population_density_miles': 2.95,
                       'population_density_ranking': 239,
                       'population_ranking': 246},
               'PER': {'alpha2': 'PE',
                       'alpha3': 'PER',
                       'area_km': 1279996,
                       'area_miles': 494207,
                       'area_ranking': 20,
                       'capital': 'Lima',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/cf/Flag_of_Peru.svg/1920px-Flag_of_Peru.svg.png',
                       'gdp': 226850000000,
                       'gdp_per_capita': 7204,
                       'gdp_per_capita_ranking': 135,
                       'gdp_ranking': 50,
                       'largest_city': 'Lima',
                       'name': 'Peru',
                       'official_name': 'Republic of Peru',
                       'population': 31488700,
                       'population_density_km': 24.6,
                       'population_density_miles': 63.72,
                       'population_density_ranking': 188,
                       'population_ranking': 41},
               'PHL': {'alpha2': 'PH',
                       'alpha3': 'PHL',
                       'area_km': 298170,
                       'area_miles': 115124,
                       'area_ranking': 72,
                       'capital': 'Manila',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/99/Flag_of_the_Philippines.svg/1920px-Flag_of_the_Philippines.svg.png',
                       'gdp': 359354000000,
                       'gdp_per_capita': 3479,
                       'gdp_per_capita_ranking': 176,
                       'gdp_ranking': 36,
                       'largest_city': 'Quezon City',
                       'name': 'Philippines',
                       'official_name': 'Republic of the Philippines',
                       'population': 103279800,
                       'population_density_km': 346.38,
                       'population_density_miles': 897.12,
                       'population_density_ranking': 39,
                       'population_ranking': 12},
               'PLW': {'alpha2': 'PW',
                       'alpha3': 'PLW',
                       'area_km': 459,
                       'area_miles': 178,
                       'area_ranking': 201,
                       'capital': 'Ngerulmud',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/48/Flag_of_Palau.svg/1920px-Flag_of_Palau.svg.png',
                       'gdp': 280000000,
                       'gdp_per_capita': 15598,
                       'gdp_per_capita_ranking': 96,
                       'gdp_ranking': 223,
                       'largest_city': 'Koror',
                       'name': 'Palau',
                       'official_name': 'Republic of Palau',
                       'population': 17950,
                       'population_density_km': 39.11,
                       'population_density_miles': 100.84,
                       'population_density_ranking': 172,
                       'population_ranking': 224},
               'PNG': {'alpha2': 'PG',
                       'alpha3': 'PNG',
                       'area_km': 452860,
                       'area_miles': 174850,
                       'area_ranking': 55,
                       'capital': 'Port Moresby',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/e3/Flag_of_Papua_New_Guinea.svg/1280px-Flag_of_Papua_New_Guinea.svg.png',
                       'gdp': 24796900000,
                       'gdp_per_capita': 3067,
                       'gdp_per_capita_ranking': 183,
                       'gdp_ranking': 109,
                       'largest_city': 'Port Moresby',
                       'name': 'Papua New Guinea',
                       'official_name': 'Independent State of Papua New Guinea',
                       'population': 8083700,
                       'population_density_km': 17.85,
                       'population_density_miles': 46.23,
                       'population_density_ranking': 203,
                       'population_ranking': 99},
               'POL': {'alpha2': 'PL',
                       'alpha3': 'POL',
                       'area_km': 311888,
                       'area_miles': 120421,
                       'area_ranking': 68,
                       'capital': 'Warsaw',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/1/12/Flag_of_Poland.svg/1920px-Flag_of_Poland.svg.png',
                       'gdp': 595862000000,
                       'gdp_per_capita': 15502,
                       'gdp_per_capita_ranking': 98,
                       'gdp_ranking': 22,
                       'largest_city': 'Warsaw',
                       'name': 'Poland',
                       'official_name': 'Republic of Poland',
                       'population': 38437239,
                       'population_density_km': 123.24,
                       'population_density_miles': 319.19,
                       'population_density_ranking': 92,
                       'population_ranking': 34},
               'PRI': {'alpha2': 'PR',
                       'alpha3': 'PRI',
                       'area_km': 9104,
                       'area_miles': 3516,
                       'area_ranking': 171,
                       'capital': 'San Juan',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/28/Flag_of_Puerto_Rico.svg/1920px-Flag_of_Puerto_Rico.svg.png',
                       'gdp': 104988000000,
                       'gdp_per_capita': 30219,
                       'gdp_per_capita_ranking': 57,
                       'gdp_ranking': 65,
                       'largest_city': 'San Juan',
                       'name': 'Puerto Rico',
                       'population': 3474182,
                       'population_density_km': 381.61,
                       'population_density_miles': 988.11,
                       'population_density_ranking': 34,
                       'population_ranking': 135},
               'PRK': {'alpha2': 'KP',
                       'alpha3': 'PRK',
                       'area_km': 120538,
                       'area_miles': 46540,
                       'area_ranking': 97,
                       'capital': 'Pyongyang',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/51/Flag_of_North_Korea.svg/2560px-Flag_of_North_Korea.svg.png',
                       'gdp': 16331000000,
                       'gdp_per_capita': 645,
                       'gdp_per_capita_ranking': 230,
                       'gdp_ranking': 126,
                       'largest_city': 'Pyongyang',
                       'name': 'North Korea',
                       'official_name': "Democratic People's Republic of Korea",
                       'population': 25281000,
                       'population_density_km': 209.73,
                       'population_density_miles': 543.21,
                       'population_density_ranking': 63,
                       'population_ranking': 50},
               'PRT': {'alpha2': 'PT',
                       'alpha3': 'PRT',
                       'area_km': 91119,
                       'area_miles': 35182,
                       'area_ranking': 109,
                       'capital': 'Lisbon',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/5c/Flag_of_Portugal.svg/1920px-Flag_of_Portugal.svg.png',
                       'gdp': 238785000000,
                       'gdp_per_capita': 23015,
                       'gdp_per_capita_ranking': 72,
                       'gdp_ranking': 49,
                       'largest_city': 'Lisbon',
                       'name': 'Portugal',
                       'official_name': 'Portuguese Republic',
                       'population': 10374822,
                       'population_density_km': 113.86,
                       'population_density_miles': 294.89,
                       'population_density_ranking': 97,
                       'population_ranking': 85},
               'PRY': {'alpha2': 'PY',
                       'alpha3': 'PRY',
                       'area_km': 397302,
                       'area_miles': 153399,
                       'area_ranking': 60,
                       'capital': 'Asunción',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/27/Flag_of_Paraguay.svg/1920px-Flag_of_Paraguay.svg.png',
                       'gdp': 38086000000,
                       'gdp_per_capita': 5556,
                       'gdp_per_capita_ranking': 149,
                       'gdp_ranking': 98,
                       'largest_city': 'Asunción',
                       'name': 'Paraguay',
                       'official_name': 'Republic of Paraguay',
                       'population': 6854536,
                       'population_density_km': 17.25,
                       'population_density_miles': 44.68,
                       'population_density_ranking': 205,
                       'population_ranking': 105},
               'PSE': {'alpha2': 'PS',
                       'alpha3': 'PSE',
                       'area_km': 6000,
                       'area_miles': 2317,
                       'area_ranking': 172,
                       'capital': 'Jerusalem (Disputed)',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/00/Flag_of_Palestine.svg/1920px-Flag_of_Palestine.svg.png',
                       'gdp': 17058000000,
                       'gdp_per_capita': 3642,
                       'gdp_per_capita_ranking': 172,
                       'gdp_ranking': 124,
                       'largest_city': 'Gaza City',
                       'name': 'Palestine',

  'official_name': 'the State of Palestine',
                       'population': 4682467,
                       'population_density_km': 780.41,
                       'population_density_miles': 2020.92,
                       'population_density_ranking': 15,
                       'population_ranking': 124},
               'PYF': {'alpha2': 'PF',
                       'alpha3': 'PYF',
                       'area_km': 4167,
                       'area_miles': 1609,
                       'area_ranking': 175,
                       'capital': 'Papeetē',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/db/Flag_of_French_Polynesia.svg/1920px-Flag_of_French_Polynesia.svg.png',
                       'gdp': 6023000000,
                       'gdp_per_capita': 22159,
                       'gdp_per_capita_ranking': 74,
                       'gdp_ranking': 164,
                       'largest_city': "Fa'a'ā",
                       'name': 'French Polynesia',
                       'population': 271800,
                       'population_density_km': 65.23,
                       'population_density_miles': 168.92,
                       'population_density_ranking': 145,
                       'population_ranking': 183},
               'QAT': {'alpha2': 'QA',
                       'alpha3': 'QAT',
                       'area_km': 11856,
                       'area_miles': 4578,
                       'area_ranking': 164,
                       'capital': 'Doha',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/65/Flag_of_Qatar.svg/1920px-Flag_of_Qatar.svg.png',
                       'gdp': 183466000000,
                       'gdp_per_capita': 70902,
                       'gdp_per_capita_ranking': 15,
                       'gdp_ranking': 54,
                       'largest_city': 'Doha',
                       'name': 'Qatar',
                       'official_name': 'State of Qatar',
                       'population': 2587564,
                       'population_density_km': 218.25,
                       'population_density_miles': 565.22,
                       'population_density_ranking': 62,
                       'population_ranking': 141},
               'REU': {'alpha2': 'RE',
                       'alpha3': 'REU',
                       'area_km': 2511,
                       'area_miles': 970,
                       'area_ranking': 180,
                       'capital': 'Saint-Denis',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/5a/Flag_of_R%C3%A9union.svg/1920px-Flag_of_R%C3%A9union.svg.png',
                       'gdp': 22000000000,
                       'gdp_per_capita': 26160,
                       'gdp_per_capita_ranking': 65,
                       'gdp_ranking': 115,
                       'largest_city': 'Saint-Denis',
                       'name': 'Réunion',
                       'population': 840974,
                       'population_density_km': 334.92,
                       'population_density_miles': 866.98,
                       'population_density_ranking': 42,
                       'population_ranking': 162},
               'ROU': {'alpha2': 'RO',
                       'alpha3': 'ROU',
                       'area_km': 231291,
                       'area_miles': 89302,
                       'area_ranking': 80,
                       'capital': 'Bucharest',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/73/Flag_of_Romania.svg/1280px-Flag_of_Romania.svg.png',
                       'gdp': 250075000000,
                       'gdp_per_capita': 12591,
                       'gdp_per_capita_ranking': 106,
                       'gdp_ranking': 48,
                       'largest_city': 'Bucharest',
                       'name': 'Romania',
                       'population': 19861408,
                       'population_density_km': 85.87,
                       'population_density_miles': 222.41,
                       'population_density_ranking': 122,
                       'population_ranking': 58},
               'RUS': {'alpha2': 'RU',
                       'alpha3': 'RUS',
                       'area_km': 16377742,
                       'area_miles': 6323453,
                       'area_ranking': 1,
                       'capital': 'Moscow',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/f/f3/Flag_of_Russia.svg/1280px-Flag_of_Russia.svg.png',
                       'gdp': 1692930000000,
                       'gdp_per_capita': 11548,
                       'gdp_per_capita_ranking': 110,
                       'gdp_ranking': 11,
                       'largest_city': 'Moscow',
                       'name': 'Russia',
                       'population': 146599183,
                       'population_density_km': 8.95,
                       'population_density_miles': 23.18,
                       'population_density_ranking': 220,
                       'population_ranking': 9},
               'RWA': {'alpha2': 'RW',
                       'alpha3': 'RWA',
                       'area_km': 24668,
                       'area_miles': 9525,
                       'area_ranking': 150,
                       'capital': 'Kigali',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/17/Flag_of_Rwanda.svg/1920px-Flag_of_Rwanda.svg.png',
                       'gdp': 10355000000,
                       'gdp_per_capita': 896,
                       'gdp_per_capita_ranking': 224,
                       'gdp_ranking': 149,
                       'largest_city': 'Kigali',
                       'name': 'Rwanda',
                       'official_name': 'Rwandese Republic',
                       'population': 11553188,
                       'population_density_km': 468.35,
                       'population_density_miles': 1212.93,
                       'population_density_ranking': 26,
                       'population_ranking': 75},
               'SAU': {'alpha2': 'SA',
                       'alpha3': 'SAU',
                       'area_km': 2149690,
                       'area_miles': 829997,
                       'area_ranking': 13,
                       'capital': 'Riyadh',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/0d/Flag_of_Saudi_Arabia.svg/1280px-Flag_of_Saudi_Arabia.svg.png',
                       'gdp': 792966000000,
                       'gdp_per_capita': 24589,
                       'gdp_per_capita_ranking': 69,
                       'gdp_ranking': 18,
                       'largest_city': 'Riyadh',
                       'name': 'Saudi Arabia',
                       'official_name': 'Kingdom of Saudi Arabia',
                       'population': 32248200,
                       'population_density_km': 15.0,
                       'population_density_miles': 38.85,
                       'population_density_ranking': 211,
                       'population_ranking': 39},
               'SDN': {'alpha2': 'SD',
                       'alpha3': 'SDN',
                       'area_km': 1731671,
                       'area_miles': 668599,
                       'area_ranking': 17,
                       'capital': 'Juba',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/01/Flag_of_Sudan.svg/1920px-Flag_of_Sudan.svg.png',
                       'gdp': 34895000000,
                       'gdp_per_capita': 2876,
                       'gdp_per_capita_ranking': 186,
                       'gdp_ranking': 99,
                       'largest_city': 'Omdurman',
                       'name': 'Sudan',
                       'official_name': 'Republic of the Sudan',
                       'population': 12131000,
                       'population_density_km': 7.01,
                       'population_density_miles': 18.14,
                       'population_density_ranking': 223,
                       'population_ranking': 73},
               'SEN': {'alpha2': 'SN',
                       'alpha3': 'SEN',
                       'area_km': 192530,
                       'area_miles': 74336,
                       'area_ranking': 86,
                       'capital': 'Dakar',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fd/Flag_of_Senegal.svg/1280px-Flag_of_Senegal.svg.png',
                       'gdp': 23664000000,
                       'gdp_per_capita': 1598,
                       'gdp_per_capita_ranking': 205,
                       'gdp_ranking': 112,
                       'largest_city': 'Dakar',
                       'name': 'Senegal',
                       'official_name': 'Republic of Senegal',
                       'population': 14799859,
                       'population_density_km': 76.87,
                       'population_density_miles': 199.09,
                       'population_density_ranking': 131,
                       'population_ranking': 70},
               'SGP': {'alpha2': 'SG',
                       'alpha3': 'SGP',
                       'area_km': 716,
                       'area_miles': 277,
                       'area_ranking': 193,
                       'capital': 'Singapore',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/48/Flag_of_Singapore.svg/1280px-Flag_of_Singapore.svg.png',
                       'gdp': 372073000000,
                       'gdp_per_capita': 67221,
                       'gdp_per_capita_ranking': 16,
                       'gdp_ranking': 33,
                       'largest_city': 'Singapore',
                       'name': 'Singapore',
                       'official_name': 'Republic of Singapore',
                       'population': 5535000,
                       'population_density_km': 7730.45,
                       'population_density_miles': 19981.95,
                       'population_density_ranking': 2,
                       'population_ranking': 114},
               'SGS': {'alpha2': 'GS',
                       'alpha3': 'SGS',
                       'area_km': 3903,
                       'area_miles': 1507,
                       'area_ranking': 177,
                       'capital': 'King Edward Point',
                       'continent': 'ANTARCTICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/ed/Flag_of_South_Georgia_and_the_South_Sandwich_Islands.svg/2560px-Flag_of_South_Georgia_and_the_South_Sandwich_Islands.svg.png',
                       'gdp': 0,
                       'gdp_per_capita': 0,
                       'gdp_per_capita_ranking': 246,
                       'gdp_ranking': 246,
                       'largest_city': 'King Edward Point',
                       'name': 'South Georgia and the South Sandwich Islands',
                       'population': 30,
                       'population_density_km': 0.01,
                       'population_density_miles': 0.02,
                       'population_density_ranking': 245,
                       'population_ranking': 247},
               'SHN': {'alpha2': 'SH',
                       'alpha3': 'SHN',
                       'area_km': 121,
                       'area_miles': 47,
                       'area_ranking': 226,
                       'capital': 'Jamestown',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/00/Flag_of_Saint_Helena.svg/2560px-Flag_of_Saint_Helena.svg.png',
                       'gdp': 51900000,
                       'gdp_per_capita': 12197,
                       'gdp_per_capita_ranking': 107,
                       'gdp_ranking': 235,
                       'largest_city': 'Half Tree Hollow',
                       'name': 'Saint Helena, Ascension and Tristan da Cunha',
                       'population': 4255,
                       'population_density_km': 35.17,
                       'population_density_miles': 90.53,
                       'population_density_ranking': 181,
                       'population_ranking': 233},
               'SJM': {'alpha2': 'SJ',
                       'alpha3': 'SJM',
                       'area_km': 61022,
                       'area_miles': 23561,
                       'area_ranking': 125,
                       'capital': 'Longyearbyen',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d9/Flag_of_Norway.svg/1920px-Flag_of_Norway.svg.png',
                       'gdp': 277300000,
                       'gdp_per_capita': 108235,
                       'gdp_per_capita_ranking': 5,
                       'gdp_ranking': 224,
                       'largest_city': 'Longyearbyen',
                       'name': 'Svalbard and Jan Mayen',
                       'population': 2562,
                       'population_density_km': 0.04,
                       'population_density_miles': 0.11,
                       'population_density_ranking': 242,
                       'population_ranking': 236},
               'SLB': {'alpha2': 'SB',
                       'alpha3': 'SLB',
                       'area_km': 27986,
                       'area_miles': 10806,
                       'area_ranking': 145,
                       'capital': 'Honiara',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/74/Flag_of_the_Solomon_Islands.svg/1920px-Flag_of_the_Solomon_Islands.svg.png',
                       'gdp': 1302000000,
                       'gdp_per_capita': 2028,
                       'gdp_per_capita_ranking': 196,
                       'gdp_ranking': 203,
                       'largest_city': 'Honiara',
                       'name': 'Solomon Islands',
                       'population': 642000,
                       'population_density_km': 22.94,
                       'population_density_miles': 59.41,
                       'population_density_ranking': 192,
                       'population_ranking': 167},
               'SLE': {'alpha2': 'SL',
                       'alpha3': 'SLE',
                       'area_km': 71620,
                       'area_miles': 27653,
                       'area_ranking': 119,
                       'capital': 'Freetown',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/17/Flag_of_Sierra_Leone.svg/1280px-Flag_of_Sierra_Leone.svg.png',
                       'gdp': 4121000000,
                       'gdp_per_capita': 582,
                       'gdp_per_capita_ranking': 233,
                       'gdp_ranking': 175,
                       'largest_city': 'Freetown',
                       'name': 'Sierra Leone',
                       'official_name': 'Republic of Sierra Leone',
                       'population': 7075641,
                       'population_density_km': 98.79,
                       'population_density_miles': 255.87,
                       'population_density_ranking': 110,
                       'population_ranking': 104},
               'SLV': {'alpha2': 'SV',
                       'alpha3': 'SLV',
                       'area_km': 20721,
                       'area_miles': 8001,
                       'area_ranking': 153,
                       'capital': 'San Salvador',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/34/Flag_of_El_Salvador.svg/1920px-Flag_of_El_Salvador.svg.png',
                       'gdp': 27022000000,
                       'gdp_per_capita': 4144,
                       'gdp_per_capita_ranking': 166,
                       'gdp_ranking': 106,
                       'largest_city': 'San Salvador',
                       'name': 'El Salvador',
                       'official_name': 'Republic of El Salvador',
                       'population': 6520675,
                       'population_density_km': 314.69,
                       'population_density_miles': 814.98,
                       'population_density_ranking': 45,
                       'population_ranking': 106},
               'SMR': {'alpha2': 'SM',
                       'alpha3': 'SMR',
                       'area_km': 61,
                       'area_miles': 24,
                       'area_ranking': 232,
                       'capital': 'City of San Marino',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b1/Flag_of_San_Marino.svg/1280px-Flag_of_San_Marino.svg.png',
                       'gdp': 1602000000,
                       'gdp_per_capita': 48538,
                       'gdp_per_capita_ranking': 30,
                       'gdp_ranking': 200,
                       'largest_city': 'Dogana',
                       'name': 'San Marino',
                       'official_name': 'Republic of San Marino',
                       'population': 33005,
                       'population_density_km': 541.07,
                       'population_density_miles': 1375.21,
                       'population_density_ranking': 22,
                       'population_ranking': 219},
               'SOM': {'alpha2': 'SO',
                       'alpha3': 'SOM',
                       'area_km': 627337,
                       'area_miles': 242216,
                       'area_ranking': 43,
                       'capital': 'Mogadishu',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/a/a0/Flag_of_Somalia.svg/1280px-Flag_of_Somalia.svg.png',
                       'gdp': 1626000000,
                       'gdp_per_capita': 146,
                       'gdp_per_capita_ranking': 242,
                       'gdp_ranking': 199,
                       'largest_city': 'Mogadishu',
                       'name': 'Somalia',
                       'official_name': 'Federal Republic of Somalia',
                       'population': 11079000,
                       'population_density_km': 17.66,
                       'population_density_miles': 45.74,
                       'population_density_ranking': 204,
                       'population_ranking': 79},
               'SPM': {'alpha2': 'PM',
                       'alpha3': 'SPM',
                       'area_km': 242,
                       'area_miles': 94,
                       'area_ranking': 217,
                       'capital': 'Saint-Pierre',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/c/c3/Flag_of_France.svg/1920px-Flag_of_France.svg.png',
                       'gdp': 261300000,
                       'gdp_per_capita': 43054,
                       'gdp_per_capita_ranking': 40,
                       'gdp_ranking': 225,
                       'largest_city': 'Saint-Pierre',
                       'name': 'Saint Pierre and Miquelon',
                       'population': 6069,
                       'population_density_km': 25.08,
                       'population_density_miles': 64.56,
                       'population_density_ranking': 187,
                       'population_ranking': 231},
               'SRB': {'alpha2': 'RS',
                       'alpha3': 'SRB',
                       'area_km': 88246,
                       'area_miles': 34072,
                       'area_ranking': 112,
                       'capital': 'Belgrade',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/ff/Flag_of_Serbia.svg/1280px-Flag_of_Serbia.svg.png',
                       'gdp': 51475000000,
                       'gdp_per_capita': 7274,
                       'gdp_per_capita_ranking': 134,
                       'gdp_ranking': 89,
                       'largest_city': 'Belgrade',
                       'name': 'Serbia',
                       'official_name': 'Republic of Serbia',
                       'population': 7076372,
                       'population_density_km': 80.19,
                       'population_density_miles': 207.69,
                       'population_density_ranking': 127,
                       'population_ranking': 103},
               'SSD': {'alpha2': 'SS',
                       'alpha3': 'SSD',
                       'area_km': 644329,
                       'area_miles': 248776,
                       'area_ranking': 42,
                       'capital': 'Juba',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/7a/Flag_of_South_Sudan.svg/1920px-Flag_of_South_Sudan.svg.png',
                       'gdp': 4959000000,
                       'gdp_per_capita': 408,
                       'gdp_per_capita_ranking': 239,
                       'gdp_ranking': 171,
                       'largest_city': 'Juba',
                       'name': 'South Sudan',
                       'official_name': 'Republic of South Sudan',
                       'population': 12131000,
                       'population_density_km': 18.83,
                       'population_density_miles': 48.76,
                       'population_density_ranking': 199,
                       'population_ranking': 74},
               'STP': {'alpha2': 'ST',
                       'alpha3': 'STP',
                       'area_km': 964,
                       'area_miles': 373,
                       'area_ranking': 188,
                       'capital': 'São Tomé',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/4f/Flag_of_Sao_Tome_and_Principe.svg/1920px-Flag_of_Sao_Tome_and_Principe.svg.png',
                       'gdp': 421000000,
                       'gdp_per_capita': 2247,
                       'gdp_per_capita_ranking': 193,
                       'gdp_ranking': 219,
                       'largest_city': 'São Tomé',
                       'name': 'Sao Tome and Principe',
                       'official_name': 'Democratic Republic of Sao Tome and Principe',
                       'population': 187356,
                       'population_density_km': 194.35,
                       'population_density_miles': 502.29,
                       'population_density_ranking': 71,
                       'population_ranking': 187},
               'SUR': {'alpha2': 'SR',
                       'alpha3': 'SUR',
                       'area_km': 156000,
                       'area_miles': 60232,
                       'area_ranking': 91,
                       'capital': 'Paramaribo',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/60/Flag_of_Suriname.svg/1280px-Flag_of_Suriname.svg.png',
                       'gdp': 3697000000,
                       'gdp_per_capita': 6825,
                       'gdp_per_capita_ranking': 137,
                       'gdp_ranking': 177,
                       'largest_city': 'Paramaribo',
                       'name': 'Suriname',
                       'official_name': 'Republic of Suriname',
                       'population': 541638,
                       'population_density_km': 3.47,
                       'population_density_miles': 8.99,
                       'population_density_ranking': 233,
                       'population_ranking': 170},
               'SVK': {'alpha2': 'SK',
                       'alpha3': 'SVK',
                       'area_km': 48105,
                       'area_miles': 18574,
                       'area_ranking': 132,
                       'capital': 'Bratislava',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/e/e6/Flag_of_Slovakia.svg/1280px-Flag_of_Slovakia.svg.png',
                       'gdp': 105079000000,
                       'gdp_per_capita': 19364,
                       'gdp_per_capita_ranking': 80,
                       'gdp_ranking': 64,
                       'largest_city': 'Bratislava',
                       'name': 'Slovakia',
                       'official_name': 'Slovak Republic',
                       'population': 5426252,
                       'population_density_km': 112.8,
                       'population_density_miles': 292.14,
                       'population_density_ranking': 99,
                       'population_ranking': 116},
               'SVN': {'alpha2': 'SI',
                       'alpha3': 'SVN',
                       'area_km': 20151,
                       'area_miles': 7781,
                       'area_ranking': 155,
                       'capital': 'Ljubljana',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/f0/Flag_of_Slovenia.svg/1920px-Flag_of_Slovenia.svg.png',
                       'gdp': 54174000000,
                       'gdp_per_capita': 26244,
                       'gdp_per_capita_ranking': 64,
                       'gdp_ranking': 87,
                       'largest_city': 'Ljubljana',
                       'name': 'Slovenia',
                       'official_name': 'Republic of Slovenia',
                       'population': 2064188,
                       'population_density_km': 102.44,
                       'population_density_miles': 265.29,
                       'population_density_ranking': 106,
                       'population_ranking': 144},
               'SWE': {'alpha2': 'SE',
                       'alpha3': 'SWE',
                       'area_km': 410335,
                       'area_miles': 158431,
                       'area_ranking': 59,
                       'capital': 'Stockholm',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/4/4c/Flag_of_Sweden.svg/1920px-Flag_of_Sweden.svg.png',
                       'gdp': 530883000000,
                       'gdp_per_capita': 53652,
                       'gdp_per_capita_ranking': 24,
                       'gdp_ranking': 25,
                       'largest_city': 'Stockholm',
                       'name': 'Sweden',
                       'official_name': 'Kingdom of Sweden',
                       'population': 9894888,
                       'population_density_km': 24.11,
                       'population_density_miles': 62.46,
                       'population_density_ranking': 191,
                       'population_ranking': 88},
               'SWZ': {'alpha2': 'SZ',
                       'alpha3': 'SWZ',
                       'area_km': 17204,
                       'area_miles': 6643,
                       'area_ranking': 159,
                       'capital': 'Lobamba',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fb/Flag_of_Eswatini.svg/1920px-Flag_of_Eswatini.svg.png',
                       'gdp': 4594000000,
                       'gdp_per_capita': 4055,
                       'gdp_per_capita_ranking': 167,
                       'gdp_ranking': 173,
                       'largest_city': 'Manzini',
                       'name': 'Eswatini',
                       'official_name': 'Kingdom of Eswatini',
                       'population': 1132657,
                       'population_density_km': 65.84,
                       'population_density_miles': 170.5,
                       'population_density_ranking': 143,
                       'population_ranking': 158},
               'SXM': {'alpha2': 'SX',
                       'alpha3': 'SXM',
                       'area_km': 34,
                       'area_miles': 14,
                       'area_ranking': 236,
                       'capital': 'Philipsburg',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d3/Flag_of_Sint_Maarten.svg/1920px-Flag_of_Sint_Maarten.svg.png',
                       'gdp': 1009000000,
                       'gdp_per_capita': 26381,
                       'gdp_per_capita_ranking': 63,
                       'gdp_ranking': 210,
                       'largest_city': "Lower Prince's Quarter",
                       'name': 'Sint Maarten',
                       'official_name': 'Sint Maarten (Dutch part)',
                       'population': 38247,
                       'population_density_km': 1124.91,
                       'population_density_miles': 2731.93,
                       'population_density_ranking': 12,
                       'population_ranking': 215},
               'SYC': {'alpha2': 'SC',
                       'alpha3': 'SYC',
                       'area_km': 455,
                       'area_miles': 176,
                       'area_ranking': 202,
                       'capital': 'Victoria',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fc/Flag_of_Seychelles.svg/1920px-Flag_of_Seychelles.svg.png',
                       'gdp': 1698000000,
                       'gdp_per_capita': 18577,
                       'gdp_per_capita_ranking': 85,
                       'gdp_ranking': 197,
                       'largest_city': 'Victoria',
                       'name': 'Seychelles',
                       'official_name': 'Republic of Seychelles',
                       'population': 91400,
                       'population_density_km': 200.88,
                       'population_density_miles': 519.32,
                       'population_density_ranking': 68,
                       'population_ranking': 199},
               'SYR': {'alpha2': 'SY',
                       'alpha3': 'SYR',
                       'area_km': 183630,
                       'area_miles': 70900,
                       'area_ranking': 88,
                       'capital': 'Damascus',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/53/Flag_of_Syria.svg/1920px-Flag_of_Syria.svg.png',
                       'gdp': 20379000000,
                       'gdp_per_capita': 1097,
                       'gdp_per_capita_ranking': 215,
                       'gdp_ranking': 117,
                       'largest_city': 'Damascus',
                       'name': 'Syria',
                       'population': 18564000,
                       'population_density_km': 101.09,
                       'population_density_miles': 261.83,
                       'population_density_ranking': 109,
                       'population_ranking': 60},
               'TCA': {'alpha2': 'TC',
                       'alpha3': 'TCA',
                       'area_km': 616,
                       'area_miles': 238,
                       'area_ranking': 195,
                       'capital': 'Cockburn Town',
                       'continent': 'NORTHERN_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/a/a0/Flag_of_the_Turks_and_Caicos_Islands.svg/2560px-Flag_of_the_Turks_and_Caicos_Islands.svg.png',
                       'gdp': 1197000000,
                       'gdp_per_capita': 38050,
                       'gdp_per_capita_ranking': 45,
                       'gdp_ranking': 206,
                       'largest_city': 'Providenciales',
                       'name': 'Turks and Caicos Islands',
                       'population': 31458,
                       'population_density_km': 51.07,
                       'population_density_miles': 132.18,
                       'population_density_ranking': 159,
                       'population_ranking': 220},
               'TCD': {'alpha2': 'TD',
                       'alpha3': 'TCD',
                       'area_km': 1259200,
                       'area_miles': 486178,
                       'area_ranking': 22,
                       'capital': "N'Djamena",
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/4b/Flag_of_Chad.svg/1024px-Flag_of_Chad.svg.png',
                       'gdp': 11271000000,
                       'gdp_per_capita': 777,
                       'gdp_per_capita_ranking': 227,
                       'gdp_ranking': 147,
                       'largest_city': "N'Djamena",
                       'name': 'Chad',
                       'official_name': 'Republic of Chad',
                       'population': 14497000,
                       'population_density_km': 11.51,
                       'population_density_miles': 29.82,
                       'population_density_ranking': 217,
                       'population_ranking': 71},
               'TGO': {'alpha2': 'TG',
                       'alpha3': 'TGO',
                       'area_km': 54385,
                       'area_miles': 20999,
                       'area_ranking': 128,
                       'capital': 'Lomé',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/68/Flag_of_Togo.svg/1920px-Flag_of_Togo.svg.png',
                       'gdp': 7270000000,
                       'gdp_per_capita': 1017,
                       'gdp_per_capita_ranking': 217,
                       'gdp_ranking': 160,
                       'largest_city': 'Lomé',
                       'name': 'Togo',
                       'official_name': 'Togolese Republic',
                       'population': 7143000,
                       'population_density_km': 131.34,
                       'population_density_miles': 340.16,
                       'population_density_ranking': 90,
                       'population_ranking': 102},
               'THA': {'alpha2': 'TH',
                       'alpha3': 'THA',
                       'area_km': 510890,
                       'area_miles': 197255,
                       'area_ranking': 51,
                       'capital': 'Bangkok',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/a/a9/Flag_of_Thailand.svg/1280px-Flag_of_Thailand.svg.png',
                       'gdp': 542016000000,
                       'gdp_per_capita': 8296,
                       'gdp_per_capita_ranking': 130,
                       'gdp_ranking': 23,
                       'largest_city': 'Bangkok',
                       'name': 'Thailand',
                       'official_name': 'Kingdom of Thailand',
                       'population': 65327652,
                       'population_density_km': 127.87,
                       'population_density_miles': 331.18,
                       'population_density_ranking': 91,
                       'population_ranking': 21},
               'TJK': {'alpha2': 'TJ',
                       'alpha3': 'TJK',
                       'area_km': 141510,
                       'area_miles': 54638,
                       'area_ranking': 94,
                       'capital': 'Dushanbe',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d0/Flag_of_Tajikistan.svg/1920px-Flag_of_Tajikistan.svg.png',
                       'gdp': 8333000000,
                       'gdp_per_capita': 969,
                       'gdp_per_capita_ranking': 219,
                       'gdp_ranking': 153,
                       'largest_city': 'Dushanbe',
                       'name': 'Tajikistan',
                       'official_name': 'Republic of Tajikistan',
                       'population': 8593600,
                       'population_density_km': 60.73,
                       'population_density_miles': 157.28,
                       'population_density_ranking': 150,
                       'population_ranking': 95},
               'TKL': {'alpha2': 'TK',
                       'alpha3': 'TKL',
                       'area_km': 10,
                       'area_miles': 4,
                       'area_ranking': 243,
                       'capital': 'Fakaofo',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/8e/Flag_of_Tokelau.svg/2560px-Flag_of_Tokelau.svg.png',
                       'gdp': 9400000,
                       'gdp_per_capita': 6661,
                       'gdp_per_capita_ranking': 139,
                       'gdp_ranking': 241,
                       'largest_city': 'Atafu',
                       'name': 'Tokelau',
                       'population': 1411,
                       'population_density_km': 141.1,
                       'population_density_miles': 352.75,
                       'population_density_ranking': 85,
                       'population_ranking': 240},
               'TKM': {'alpha2': 'TM',
                       'alpha3': 'TKM',
                       'area_km': 469930,
                       'area_miles': 181441,
                       'area_ranking': 54,
                       'capital': 'Ashgabat',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/1/1b/Flag_of_Turkmenistan.svg/1280px-Flag_of_Turkmenistan.svg.png',
                       'gdp': 48276000000,
                       'gdp_per_capita': 10160,
                       'gdp_per_capita_ranking': 118,
                       'gdp_ranking': 90,
                       'largest_city': 'Ashgabat',
                       'name': 'Turkmenistan',
                       'population': 4751120,
                       'population_density_km': 10.11,
                       'population_density_miles': 26.19,
                       'population_density_ranking': 219,
                       'population_ranking': 121},
               'TLS': {'alpha2': 'TL',
                       'alpha3': 'TLS',
                       'area_km': 15007,
                       'area_miles': 5795,
                       'area_ranking': 160,
                       'capital': 'Dili',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/26/Flag_of_East_Timor.svg/1920px-Flag_of_East_Timor.svg.png',
                       'gdp': 2017000000,
                       'gdp_per_capita': 1728,
                       'gdp_per_capita_ranking': 202,
                       'gdp_ranking': 192,
                       'largest_city': 'Dili',
                       'name': 'Timor-Leste',
                       'official_name': 'Democratic Republic of Timor-Leste',
                       'population': 1167242,
                       'population_density_km': 77.78,
                       'population_density_miles': 201.42,
                       'population_density_ranking': 130,
                       'population_ranking': 157},
               'TON': {'alpha2': 'TO',
                       'alpha3': 'TON',
                       'area_km': 717,
                       'area_miles': 277,
                       'area_ranking': 192,
                       'capital': "Nuku'alofa",
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/9/9a/Flag_of_Tonga.svg/2560px-Flag_of_Tonga.svg.png',
                       'gdp': 508000000,
                       'gdp_per_capita': 4920,
                       'gdp_per_capita_ranking': 155,
                       'gdp_ranking': 218,
                       'largest_city': 'Nukuʻalofa',
                       'name': 'Tonga',
                       'official_name': 'Kingdom of Tonga',
                       'population': 103252,
                       'population_density_km': 144.01,
                       'population_density_miles': 372.75,
                       'population_density_ranking': 83,
                       'population_ranking': 196},
               'TTO': {'alpha2': 'TT',
                       'alpha3': 'TTO',
                       'area_km': 5128,
                       'area_miles': 1980,
                       'area_ranking': 174,
                       'capital': 'Port of Spain',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/64/Flag_of_Trinidad_and_Tobago.svg/1920px-Flag_of_Trinidad_and_Tobago.svg.png',
                       'gdp': 23208000000,
                       'gdp_per_capita': 17195,
                       'gdp_per_capita_ranking': 90,
                       'gdp_ranking': 113,
                       'largest_city': 'San Fernando',
                       'name': 'Trinidad and Tobago',
                       'official_name': 'Republic of Trinidad and Tobago',
                       'population': 1349667,
                       'population_density_km': 263.2,
                       'population_density_miles': 681.65,
                       'population_density_ranking': 53,
                       'population_ranking': 152},
               'TUN': {'alpha2': 'TN',
                       'alpha3': 'TUN',
                       'area_km': 155360,
                       'area_miles': 59985,
                       'area_ranking': 92,
                       'capital': 'Tunis',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/c/ce/Flag_of_Tunisia.svg/1280px-Flag_of_Tunisia.svg.png',
                       'gdp': 38797000000,
                       'gdp_per_capita': 3478,
                       'gdp_per_capita_ranking': 177,
                       'gdp_ranking': 96,
                       'largest_city': 'Tunis',
                       'name': 'Tunisia',
                       'official_name': 'Republic of Tunisia',
                       'population': 11154400,
                       'population_density_km': 71.8,
                       'population_density_miles': 185.95,
                       'population_density_ranking': 138,
                       'population_ranking': 78},
               'TUR': {'alpha2': 'TR',
                       'alpha3': 'TUR',
                       'area_km': 769632,
                       'area_miles': 297156,
                       'area_ranking': 37,
                       'capital': 'Ankara',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/b/b4/Flag_of_Turkey.svg/1280px-Flag_of_Turkey.svg.png',
                       'gdp': 761425000000,
                       'gdp_per_capita': 9669,
                       'gdp_per_capita_ranking': 120,
                       'gdp_ranking': 19,
                       'largest_city': 'Istanbul',
                       'name': 'Turkey',
                       'official_name': 'Republic of Turkey',
                       'population': 78741053,
                       'population_density_km': 102.31,
                       'population_density_miles': 264.98,
                       'population_density_ranking': 107,
                       'population_ranking': 19},
               'TUV': {'alpha2': 'TV',
                       'alpha3': 'TUV',
                       'area_km': 26,
                       'area_miles': 11,
                       'area_ranking': 238,
                       'capital': 'Funafuti',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/38/Flag_of_Tuvalu.svg/1920px-Flag_of_Tuvalu.svg.png',
                       'gdp': 47000000,
                       'gdp_per_capita': 4417,
                       'gdp_per_capita_ranking': 161,
                       'gdp_ranking': 236,
                       'largest_city': 'Funafuti',
                       'name': 'Tuvalu',
                       'population': 10640,
                       'population_density_km': 409.23,
                       'population_density_miles': 967.27,
                       'population_density_ranking': 31,
                       'population_ranking': 228},
               'TWN': {'alpha2': 'TW',
                       'alpha3': 'TWN',
                       'area_km': 32260,
                       'area_miles': 12456,
                       'area_ranking': 139,
                       'capital': 'Taipei',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/72/Flag_of_the_Republic_of_China.svg/1920px-Flag_of_the_Republic_of_China.svg.png',
                       'gdp': 315020000000,
                       'gdp_per_capita': 13403,
                       'gdp_per_capita_ranking': 103,
                       'gdp_ranking': 42,
                       'largest_city': 'New Taipei',
                       'name': 'Taiwan',
                       'official_name': 'Taiwan, Province of China',
                       'population': 23503349,
                       'population_density_km': 728.56,
                       'population_density_miles': 1886.91,
                       'population_density_ranking': 16,
                       'population_ranking': 52},
               'TZA': {'alpha2': 'TZ',
                       'alpha3': 'TZA',
                       'area_km': 885800,
                       'area_miles': 342008,
                       'area_ranking': 32,
                       'capital': 'Dodoma',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/38/Flag_of_Tanzania.svg/1280px-Flag_of_Tanzania.svg.png',
                       'gdp': 61136000000,
                       'gdp_per_capita': 1108,
                       'gdp_per_capita_ranking': 214,
                       'gdp_ranking': 80,
                       'largest_city': 'Dar es Salaam',
                       'name': 'Tanzania',
                       'official_name': 'United Republic of Tanzania',
                       'population': 55155000,
                       'population_density_km': 62.27,
                       'population_density_miles': 161.27,
                       'population_density_ranking': 149,
                       'population_ranking': 25},
               'UGA': {'alpha2': 'UG',
                       'alpha3': 'UGA',
                       'area_km': 197100,
                       'area_miles': 76101,
                       'area_ranking': 84,
                       'capital': 'Kampala',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/4e/Flag_of_Uganda.svg/1280px-Flag_of_Uganda.svg.png',
                       'gdp': 32609000000,
                       'gdp_per_capita': 963,
                       'gdp_per_capita_ranking': 221,
                       'gdp_ranking': 101,
                       'largest_city': 'Kampala',
                       'name': 'Uganda',
                       'official_name': 'Republic of Uganda',
                       'population': 33860700,
                       'population_density_km': 171.79,
                       'population_density_miles': 444.94,
                       'population_density_ranking': 76,
                       'population_ranking': 37},
               'UKR': {'alpha2': 'UA',
                       'alpha3': 'UKR',
                       'area_km': 579300,
                       'area_miles': 223668,
                       'area_ranking': 46,
                       'capital': 'Kiev',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/49/Flag_of_Ukraine.svg/1280px-Flag_of_Ukraine.svg.png',
                       'gdp': 153781000000,
                       'gdp_per_capita': 3602,
                       'gdp_per_capita_ranking': 173,
                       'gdp_ranking': 58,
                       'largest_city': 'Kyiv',
                       'name': 'Ukraine',
                       'population': 42692393,
                       'population_density_km': 73.7,
                       'population_density_miles': 190.87,
                       'population_density_ranking': 137,
                       'population_ranking': 32},
               'UMI': {'alpha2': 'UM',
                       'alpha3': 'UMI',
                       'area_km': 34,
                       'area_miles': 14,
                       'area_ranking': 237,
                       'capital': 'Washington, D.C.',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/a/a4/Flag_of_the_United_States.svg/1920px-Flag_of_the_United_States.svg.png',
                       'gdp': 13000000,
                       'gdp_per_capita': 43333,
                       'gdp_per_capita_ranking': 39,
                       'gdp_ranking': 238,
                       'largest_city': 'New York City',
                       'name': 'United States Minor Outlying Islands',
                       'population': 300,
                       'population_density_km': 8.82,
                       'population_density_miles': 21.43,
                       'population_density_ranking': 221,
                       'population_ranking': 244},
               'URY': {'alpha2': 'UY',
                       'alpha3': 'URY',
                       'area_km': 175015,
                       'area_miles': 67574,
                       'area_ranking': 90,
                       'capital': 'Montevideo',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/fe/Flag_of_Uruguay.svg/1280px-Flag_of_Uruguay.svg.png',
                       'gdp': 56045000000,
                       'gdp_per_capita': 16103,
                       'gdp_per_capita_ranking': 94,
                       'gdp_ranking': 85,
                       'largest_city': 'Montevideo',
                       'name': 'Uruguay',
                       'official_name': 'Eastern Republic of Uruguay',
                       'population': 3480222,
                       'population_density_km': 19.89,
                       'population_density_miles': 51.5,
                       'population_density_ranking': 198,
                       'population_ranking': 134},
               'USA': {'alpha2': 'US',
                       'alpha3': 'USA',
                       'area_km': 9147593,
                       'area_miles': 3531890,
                       'area_ranking': 3,
                       'capital': 'Washington, D.C.',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/en/thumb/a/a4/Flag_of_the_United_States.svg/1920px-Flag_of_the_United_States.svg.png',
                       'gdp': 21433226000000,
                       'gdp_per_capita': 66162,
                       'gdp_per_capita_ranking': 17,
                       'gdp_ranking': 1,
                       'largest_city': 'New York City',
                       'name': 'United States',
                       'official_name': 'United States of America',
                       'population': 323947000,
                       'population_density_km': 35.41,
                       'population_density_miles': 91.72,
                       'population_density_ranking': 178,
                       'population_ranking': 3},
               'UZB': {'alpha2': 'UZ',
                       'alpha3': 'UZB',
                       'area_km': 425400,
                       'area_miles': 164248,
                       'area_ranking': 58,
                       'capital': 'Tashkent',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/84/Flag_of_Uzbekistan.svg/1920px-Flag_of_Uzbekistan.svg.png',
                       'gdp': 57921000000,
                       'gdp_per_capita': 1834,
                       'gdp_per_capita_ranking': 200,
                       'gdp_ranking': 83,
                       'largest_city': 'Tashkent',
                       'name': 'Uzbekistan',
                       'official_name': 'Republic of Uzbekistan',
                       'population': 31576400,
                       'population_density_km': 74.23,
                       'population_density_miles': 192.25,
                       'population_density_ranking': 136,
                       'population_ranking': 40},
               'VAT': {'alpha2': 'VA',
                       'alpha3': 'VAT',
                       'area_km': 1,
                       'area_miles': 1,
                       'area_ranking': 246,
                       'capital': 'Vatican City',
                       'continent': 'EUROPE',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/00/Flag_of_the_Vatican_City.svg/1280px-Flag_of_the_Vatican_City.svg.png',
                       'gdp': 21200000,
                       'gdp_per_capita': 47006,
                       'gdp_per_capita_ranking': 34,
                       'gdp_ranking': 237,
                       'largest_city': 'Vatican City',
                       'name': 'Vatican City',
                       'population': 451,
                       'population_density_km': 451.0,
                       'population_density_miles': 451.0,
                       'population_density_ranking': 28,
                       'population_ranking': 243},
               'VCT': {'alpha2': 'VC',
                       'alpha3': 'VCT',
                       'area_km': 389,
                       'area_miles': 151,
                       'area_ranking': 206,
                       'capital': 'Kingstown',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/6d/Flag_of_Saint_Vincent_and_the_Grenadines.svg/1920px-Flag_of_Saint_Vincent_and_the_Grenadines.svg.png',
                       'gdp': 825000000,
                       'gdp_per_capita': 7500,
                       'gdp_per_capita_ranking': 133,
                       'gdp_ranking': 213,
                       'largest_city': 'Kingstown',
                       'name': 'Saint Vincent and the Grenadines',
                       'population': 109991,
                       'population_density_km': 282.75,
                       'population_density_miles': 728.42,
                       'population_density_ranking': 51,
                       'population_ranking': 193},
               'VEN': {'alpha2': 'VE',
                       'alpha3': 'VEN',
                       'area_km': 882050,
                       'area_miles': 340560,
                       'area_ranking': 34,
                       'capital': 'Caracas',
                       'continent': 'SOUTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/7/7b/Flag_of_Venezuela_%28state%29.svg/1280px-Flag_of_Venezuela_%28state%29.svg.png',
                       'gdp': 134960000000,
                       'gdp_per_capita': 4349,
                       'gdp_per_capita_ranking': 162,
                       'gdp_ranking': 59,
                       'largest_city': 'Caracas',
                       'name': 'Venezuela',
                       'official_name': 'Bolivarian Republic of Venezuela',
                       'population': 31028700,
                       'population_density_km': 35.18,
                       'population_density_miles': 91.11,
                       'population_density_ranking': 180,
                       'population_ranking': 43},
               'VGB': {'alpha2': 'VG',
                       'alpha3': 'VGB',
                       'area_km': 153,
                       'area_miles': 60,
                       'area_ranking': 223,
                       'capital': 'Road Town',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/4/42/Flag_of_the_British_Virgin_Islands.svg/2560px-Flag_of_the_British_Virgin_Islands.svg.png',
                       'gdp': 1296000000,
                       'gdp_per_capita': 45451,
                       'gdp_per_capita_ranking': 36,
                       'gdp_ranking': 204,
                       'largest_city': 'Road Town',
                       'name': 'British Virgin Islands',
                       'official_name': 'British Virgin Islands',
                       'population': 28514,
                       'population_density_km': 186.37,
                       'population_density_miles': 475.23,
                       'population_density_ranking': 73,
                       'population_ranking': 222},
               'VIR': {'alpha2': 'VI',
                       'alpha3': 'VIR',
                       'area_km': 346,
                       'area_miles': 134,
                       'area_ranking': 209,
                       'capital': 'Charlotte Amalie',
                       'continent': 'NORTH_AMERICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/f/f8/Flag_of_the_United_States_Virgin_Islands.svg/1920px-Flag_of_the_United_States_Virgin_Islands.svg.png',
                       'gdp': 3984000000,
                       'gdp_per_capita': 34721,
                       'gdp_per_capita_ranking': 49,
                       'gdp_ranking': 176,
                       'largest_city': 'Charlotte Amalie',
                       'name': 'U.S. Virgin Islands',
                       'official_name': 'Virgin Islands of the United States',
                       'population': 114743,
                       'population_density_km': 331.63,
                       'population_density_miles': 856.29,
                       'population_density_ranking': 44,
                       'population_ranking': 191},
               'VNM': {'alpha2': 'VN',
                       'alpha3': 'VNM',
                       'area_km': 310070,
                       'area_miles': 119719,
                       'area_ranking': 69,
                       'capital': 'Hanoi',
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/21/Flag_of_Vietnam.svg/1280px-Flag_of_Vietnam.svg.png',
                       'gdp': 261921000000,
                       'gdp_per_capita': 2825,
                       'gdp_per_capita_ranking': 187,
                       'gdp_ranking': 46,
                       'largest_city': 'Ho Chi Minh City',
                       'name': 'Vietnam',
                       'official_name': 'Socialist Republic of Viet Nam',
                       'population': 92700000,
                       'population_density_km': 298.96,
                       'population_density_miles': 774.31,
                       'population_density_ranking': 49,
                       'population_ranking': 13},
               'VUT': {'alpha2': 'VU',
                       'alpha3': 'VUT',
                       'area_km': 12189,
                       'area_miles': 4707,
                       'area_ranking': 162,
                       'capital': 'Port Vila',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/6e/Flag_of_Vanuatu_%28official%29.svg/1920px-Flag_of_Vanuatu_%28official%29.svg.png',
                       'gdp': 906000000,
                       'gdp_per_capita': 3264,
                       'gdp_per_capita_ranking': 182,
                       'gdp_ranking': 211,
                       'largest_city': 'Port Vila',
                       'name': 'Vanuatu',
                       'official_name': 'Republic of Vanuatu',
                       'population': 277500,
                       'population_density_km': 22.77,
                       'population_density_miles': 58.95,
                       'population_density_ranking': 193,
                       'population_ranking': 182},
               'WLF': {'alpha2': 'WF',
                       'alpha3': 'WLF',
                       'area_km': 142,
                       'area_miles': 55,
                       'area_ranking': 224,
                       'capital': 'Mata-Utu',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/d/d2/Flag_of_Wallis_and_Futuna.svg/1920px-Flag_of_Wallis_and_Futuna.svg.png',
                       'gdp': 188000000,
                       'gdp_per_capita': 16000,
                       'gdp_per_capita_ranking': 95,
                       'gdp_ranking': 230,
                       'largest_city': "Matā'Utu",
                       'name': 'Wallis and Futuna',
                       'population': 11750,
                       'population_density_km': 82.75,
                       'population_density_miles': 213.64,
                       'population_density_ranking': 125,
                       'population_ranking': 227},
               'WSM': {'alpha2': 'WS',
                       'alpha3': 'WSM',
                       'area_km': 2821,
                       'area_miles': 1090,
                       'area_ranking': 178,
                       'capital': 'Pago Pago',
                       'continent': 'OCEANIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/31/Flag_of_Samoa.svg/1920px-Flag_of_Samoa.svg.png',
                       'gdp': 844000000,
                       'gdp_per_capita': 14781,
                       'gdp_per_capita_ranking': 99,
                       'gdp_ranking': 212,
                       'largest_city': 'Apia',
                       'name': 'Samoa',
                       'official_name': 'Independent State of Samoa',
                       'population': 57100,
                       'population_density_km': 20.24,
                       'population_density_miles': 52.39,
                       'population_density_ranking': 196,
                       'population_ranking': 208},
               'YEM': {'alpha2': 'YE',
                       'alpha3': 'YEM',
                       'area_km': 527968,
                       'area_miles': 203849,
                       'area_ranking': 50,
                       'capital': "Sana'a",
                       'continent': 'ASIA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/8/89/Flag_of_Yemen.svg/1280px-Flag_of_Yemen.svg.png',
                       'gdp': 24935000000,
                       'gdp_per_capita': 907,
                       'gdp_per_capita_ranking': 223,
                       'gdp_ranking': 108,
                       'largest_city': "Sana'a",
                       'name': 'Yemen',
                       'official_name': 'Republic of Yemen',
                       'population': 27478000,
                       'population_density_km': 52.04,
                       'population_density_miles': 134.8,
                       'population_density_ranking': 156,
                       'population_ranking': 47},
               'ZAF': {'alpha2': 'ZA',
                       'alpha3': 'ZAF',
                       'area_km': 1214470,
                       'area_miles': 468908,
                       'area_ranking': 25,
                       'capital': 'Pretoria',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/a/af/Flag_of_South_Africa.svg/1280px-Flag_of_South_Africa.svg.png',
                       'gdp': 351430000000,
                       'gdp_per_capita': 6314,
                       'gdp_per_capita_ranking': 144,
                       'gdp_ranking': 37,
                       'largest_city': 'Johannesburg',
                       'name': 'South Africa',
                       'official_name': 'Republic of South Africa',
                       'population': 55653654,
                       'population_density_km': 45.83,
                       'population_density_miles': 118.69,
                       'population_density_ranking': 167,
                       'population_ranking': 24},
               'ZMB': {'alpha2': 'ZM',
                       'alpha3': 'ZMB',
                       'area_km': 743398,
                       'area_miles': 287027,
                       'area_ranking': 39,
                       'capital': 'Lusaka',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/0/06/Flag_of_Zambia.svg/1280px-Flag_of_Zambia.svg.png',
                       'gdp': 23085000000,
                       'gdp_per_capita': 1448,
                       'gdp_per_capita_ranking': 208,
                       'gdp_ranking': 114,
                       'largest_city': 'Lusaka',
                       'name': 'Zambia',
                       'official_name': 'Republic of Zambia',
                       'population': 15933883,
                       'population_density_km': 21.43,
                       'population_density_miles': 55.51,
                       'population_density_ranking': 194,
                       'population_ranking': 68},
               'ZWE': {'alpha2': 'ZW',
                       'alpha3': 'ZWE',
                       'area_km': 386847,
                       'area_miles': 149362,
                       'area_ranking': 61,
                       'capital': 'Harare',
                       'continent': 'AFRICA',
                       'flag_url': 'https://upload.wikimedia.org/wikipedia/commons/thumb/6/6a/Flag_of_Zimbabwe.svg/1920px-Flag_of_Zimbabwe.svg.png',
                       'gdp': 21440000000,
                       'gdp_per_capita': 1505,
                       'gdp_per_capita_ranking': 206,
                       'gdp_ranking': 116,
                       'largest_city': 'Harare',
                       'name': 'Zimbabwe',
                       'official_name': 'Republic of Zimbabwe',
                       'population': 14240168,
                       'population_density_km': 36.81,
                       'population_density_miles': 95.34,
                       'population_density_ranking': 177,
                       'population_ranking': 72}}